@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.h
  * \brief Header including structures, macros and prototypes for client handling
- * \version $Id: client.h 9233 2020-01-31 17:31:08Z michael $
+ * \version $Id: client.h 9889 2021-01-16 17:03:49Z michael $
  */
 
 
@@ -92,7 +92,7 @@ enum
 enum
 {
   TS_CURRENT = 6,  /**< Current TS protocol version */
-  TS_MIN     = 6   /**< Minimum supported TS protocol version */
+  TS_MINIMUM = 6,  /**< Minimum supported TS protocol version */
 };
 
 enum
@@ -103,10 +103,11 @@ enum
   CAP_EXTENDED_JOIN  = 1 << 3,  /**< ircv3.1 extended-join client capability */
   CAP_ACCOUNT_NOTIFY = 1 << 4,  /**< ircv3.1 account-notify client capability */
   CAP_INVITE_NOTIFY  = 1 << 5,  /**< ircv3.2 invite-notify client capability */
-  CAP_CHGHOST        = 1 << 6   /**< ircv3.2 chghost client capability */
+  CAP_CHGHOST        = 1 << 6,  /**< ircv3.2 chghost client capability */
+  CAP_CAP_NOTIFY     = 1 << 7,  /**< ircv3 CAP LS 302 cap-notify client capability */
 };
 
-#define HasCap(x, y) ((x)->connection->cap_active & (y))
+#define HasCap(x, y) ((x)->connection->cap & (y))
 
 
 /* housekeeping flags */
@@ -135,7 +136,8 @@ enum
   FLAGS_SERVICE       = 1 << 20,  /**< Client/server is a network service */
   FLAGS_TLS           = 1 << 21,  /**< User is connected via TLS (Transport Layer Security) */
   FLAGS_SQUIT         = 1 << 22,
-  FLAGS_EXEMPTXLINE   = 1 << 23   /**< Client is exempt from x-lines */
+  FLAGS_EXEMPTXLINE   = 1 << 23,  /**< Client is exempt from x-lines */
+  FLAGS_CAP302        = 1 << 24  /**< Client supports the IRCv3 CAP 302 extension */
 };
 
 #define HasFlag(x, y) ((x)->flags &   (y))
@@ -150,30 +152,29 @@ enum
   UMODE_CCONN        = 1 <<  1,  /**< Can see client connection notices */
   UMODE_REJ          = 1 <<  2,  /**< Bot Rejections */
   UMODE_SKILL        = 1 <<  3,  /**< Server Killed */
-  UMODE_FULL         = 1 <<  4,  /**< Full messages */
+  UMODE_FLOOD        = 1 <<  4,  /**< Flooding/spambot notices */
   UMODE_SPY          = 1 <<  5,  /**< See STATS / LINKS */
   UMODE_DEBUG        = 1 <<  6,  /**< 'debugging' info */
   UMODE_NCHANGE      = 1 <<  7,  /**< Nick change notice */
   UMODE_WALLOP       = 1 <<  8,  /**< Send wallops to them */
   UMODE_INVISIBLE    = 1 <<  9,  /**< Makes user invisible */
-  UMODE_BOTS         = 1 << 10,  /**< Shows bots */
-  UMODE_EXTERNAL     = 1 << 11,  /**< Show servers introduced and splitting */
-  UMODE_CALLERID     = 1 << 12,  /**< Block unless caller id's */
-  UMODE_SOFTCALLERID = 1 << 13,  /**< Block unless on common channel */
-  UMODE_UNAUTH       = 1 << 14,  /**< Show unauth connects here */
-  UMODE_LOCOPS       = 1 << 15,  /**< Can see LOCOPS messages */
-  UMODE_DEAF         = 1 << 16,  /**< Don't receive channel messages */
-  UMODE_REGISTERED   = 1 << 17,  /**< User has identified for that nick. */
-  UMODE_REGONLY      = 1 << 18,  /**< Only registered nicks may PM */
-  UMODE_HIDDEN       = 1 << 19,  /**< IRC operator status is hidden */
-  UMODE_OPER         = 1 << 20,  /**< IRC operator */
-  UMODE_ADMIN        = 1 << 21,  /**< Admin on server */
-  UMODE_FARCONNECT   = 1 << 22,  /**< Can see remote client connects/exits */
-  UMODE_SECURE       = 1 << 23,  /**< User is connected via TLS */
-  UMODE_WEBIRC       = 1 << 24,  /**< User connected via a webirc gateway */
-  UMODE_HIDEIDLE     = 1 << 25,  /**< Hides idle and signon time in WHOIS */
-  UMODE_HIDECHANS    = 1 << 26,  /**< Hides channel list in WHOIS */
-  UMODE_EXPIRATION   = 1 << 27   /**< Receives *LINE expiration notices */
+  UMODE_EXTERNAL     = 1 << 10,  /**< Show servers introduced and splitting */
+  UMODE_CALLERID     = 1 << 11,  /**< Block unless caller id's */
+  UMODE_SOFTCALLERID = 1 << 12,  /**< Block unless on common channel */
+  UMODE_LOCOPS       = 1 << 13,  /**< Can see LOCOPS messages */
+  UMODE_DEAF         = 1 << 14,  /**< Don't receive channel messages */
+  UMODE_REGISTERED   = 1 << 15,  /**< User has identified for that nick. */
+  UMODE_REGONLY      = 1 << 16,  /**< Only registered nicks may PM */
+  UMODE_HIDDEN       = 1 << 17,  /**< IRC operator status is hidden */
+  UMODE_OPER         = 1 << 18,  /**< IRC operator */
+  UMODE_ADMIN        = 1 << 19,  /**< Admin on server */
+  UMODE_FARCONNECT   = 1 << 20,  /**< Can see remote client connects/exits */
+  UMODE_SECURE       = 1 << 21,  /**< User is connected via TLS */
+  UMODE_WEBIRC       = 1 << 22,  /**< User connected via a webirc gateway */
+  UMODE_HIDEIDLE     = 1 << 23,  /**< Hides idle and signon time in WHOIS */
+  UMODE_HIDECHANS    = 1 << 24,  /**< Hides channel list in WHOIS */
+  UMODE_EXPIRATION   = 1 << 25,  /**< Receives *LINE expiration notices */
+  UMODE_BOT          = 1 << 26  /**< Client is marked as a bot in WHOIS and WHO */
 };
 
 #define HasUMode(x, y) ((x)->umodes &   (y))
@@ -290,9 +291,8 @@ struct Connection
   dlink_node lclient_node;
 
   unsigned int registration;
-  unsigned int cap_client;  /**< Client capabilities (from us) */
-  unsigned int cap_active;  /**< Active capabilities (to us) */
-  unsigned int caps;  /**< Capabilities bit-field */
+  unsigned int cap;  /**< Client CAP bit-field */
+  unsigned int capab;  /**< Server CAPAB bit field */
 
   unsigned int operflags;     /**< IRC Operator privilege flags */
   unsigned int random_ping; /**< Holding a 32bit value used for PING cookies */
@@ -333,7 +333,7 @@ struct Connection
   struct AuthRequest *auth;
   struct Listener *listener;  /**< Listener accepted from */
   dlink_list acceptlist;  /**< Clients I'll allow to talk to me */
-  dlink_list watches;  /**< Chain of Watch pointer blocks */
+  dlink_list monitors;  /**< Chain of Monitor pointer blocks */
   dlink_list confs;  /**< Configuration record associated */
   dlink_list invited;  /**< Chain of invite pointer blocks */
 
@@ -376,7 +376,8 @@ struct Client
 
   struct irc_ssaddr ip;  /**< Real IP address */
 
-  char *certfp;  /**< TLS certificate fingerprint */
+  char *tls_certfp;  /**< TLS certificate fingerprint */
+  char *tls_cipher;  /**< Exact copy of tls_get_cipher() */
 
   char away[AWAYLEN + 1];  /**< Client's AWAY message. Can be set/unset via AWAY command */
   char name[HOSTLEN + 1];  /**< Unique name for a client nick or host */
@@ -422,6 +423,15 @@ struct Client
 };
 
 
+struct AcceptItem
+{
+  dlink_node node;
+  char *nick;
+  char *user;
+  char *host;
+};
+
+
 extern struct Client me;
 extern dlink_list listing_client_list;
 extern dlink_list global_client_list;
@@ -433,11 +443,11 @@ extern dlink_list oper_list;          /* our opers, duplicated in local_client_l
 
 extern bool accept_message(struct Client *, struct Client *);
 extern unsigned int client_get_idle_time(const struct Client *, const struct Client *);
-extern struct split_nuh_item *find_accept(const char *, const char *,
-                                          const char *, struct Client *,
+extern struct AcceptItem *accept_find(const char *, const char *,
+                                          const char *, dlink_list *,
                                           int (*)(const char *, const char *));
-extern void del_accept(struct split_nuh_item *, struct Client *);
-extern void del_all_accepts(struct Client *);
+extern void accept_del(struct AcceptItem *, dlink_list *);
+extern void accept_clear_list(dlink_list *);
 extern void exit_client(struct Client *, const char *);
 extern void conf_try_ban(struct Client *, int, const char *);
 extern void check_conf_klines(void);
