@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2019 ircd-hybrid development team
+ *  Copyright (c) 2000-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file event.h
  * \brief Timer based event execution
- * \version $Id: event.h 8901 2019-04-21 20:10:44Z michael $
+ * \version $Id: event.h 9858 2021-01-01 04:43:42Z michael $
  */
 
 #ifndef INCLUDED_event_h
@@ -37,7 +37,7 @@ struct event_base
   } time;
 };
 
-struct event_base *event_base;
+extern struct event_base *event_base;
 
 struct event
 {
