@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ipcache.h
  * \brief Routines to count connections from particular IP addresses.
- * \version $Id: ipcache.h 8928 2019-04-22 18:09:43Z michael $
+ * \version $Id: ipcache.h 9858 2021-01-01 04:43:42Z michael $
  */
 
 #ifndef INCLUDED_ipcache_h
@@ -38,7 +38,7 @@ struct ip_entry
 };
 
 extern struct ip_entry *ipcache_record_find_or_add(void *);
-extern void ipcache_record_remove(void *, int);
+extern void ipcache_record_remove(void *, bool);
 extern void ipcache_get_stats(unsigned int *const, size_t *const);
 extern void ipcache_init(void);
 #endif
