@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2019 ircd-hybrid development team
+ *  Copyright (c) 1999-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file irc_string.h
  * \brief A header for the ircd string functions.
- * \version $Id: irc_string.h 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: irc_string.h 9876 2021-01-09 14:19:29Z michael $
  */
 
 #ifndef INCLUDED_irc_string_h
@@ -70,10 +70,6 @@ extern const char *stripws(char *);
 
 #define EmptyString(x) (!(x) || (*(x) == '\0'))
 
-#ifndef HAVE_STRTOK_R
-extern char *strtok_r(char *, const char *, char **);
-#endif
-
 /*
  * character macros
  */
@@ -103,12 +99,14 @@ enum
   SERV_C    = 1 << 13,
   EOL_C     = 1 << 14,
   MWILD_C   = 1 << 15,
-  VCHAN_C   = 1 << 16
+  VCHAN_C   = 1 << 16,
+  USER2_C   = 1 << 17,
 };
 
 #define IsVisibleChanChar(c)   (CharAttrs[(unsigned char)(c)] & VCHAN_C)
 #define IsHostChar(c)   (CharAttrs[(unsigned char)(c)] & HOST_C)
 #define IsUserChar(c)   (CharAttrs[(unsigned char)(c)] & USER_C)
+#define IsUser2Char(c)  (CharAttrs[(unsigned char)(c)] & USER2_C)
 #define IsChanPrefix(c) (CharAttrs[(unsigned char)(c)] & CHANPFX_C)
 #define IsChanChar(c)   (CharAttrs[(unsigned char)(c)] & CHAN_C)
 #define IsKWildChar(c)  (CharAttrs[(unsigned char)(c)] & KWILD_C)
