@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file numeric.h
  * \brief Declarations of numeric replies.
- * \version $Id: numeric.h 9291 2020-02-23 10:33:32Z michael $
+ * \version $Id: numeric.h 9858 2021-01-01 04:43:42Z michael $
  */
 
 #ifndef INCLUDED_numeric_h
@@ -123,10 +123,11 @@ enum irc_numerics
   RPL_NOTOPIC              = 331,
   RPL_TOPIC                = 332,
   RPL_TOPICWHOTIME         = 333,
-  RPL_WHOISTEXT            = 335,
+  RPL_WHOISBOT             = 335,
   RPL_INVITELIST           = 336,
   RPL_ENDOFINVITELIST      = 337,
   RPL_WHOISACTUALLY        = 338,
+  RPL_WHOISTEXT            = 339,
   RPL_INVITING             = 341,
   RPL_INVEXLIST            = 346,
   RPL_ENDOFINVEXLIST       = 347,
@@ -204,6 +205,7 @@ enum irc_numerics
   ERR_NEEDREGGEDNICK       = 477,
   ERR_BANLISTFULL          = 478,
   ERR_BADCHANNAME          = 479,
+  ERR_CANNOTKNOCK          = 480,
   ERR_NOPRIVILEGES         = 481,
   ERR_CHANOPRIVSNEEDED     = 482,
   ERR_CANTKILLSERVER       = 483,
@@ -215,20 +217,11 @@ enum irc_numerics
   ERR_UMODEUNKNOWNFLAG     = 501,
   ERR_USERSDONTMATCH       = 502,
   ERR_USERNOTONSERV        = 504,
-  ERR_TOOMANYWATCH         = 512,
   ERR_WRONGPONG            = 513,
   ERR_OPERONLYCHAN         = 520,
   ERR_LISTSYNTAX           = 521,
   ERR_WHOLIMEXCEED         = 523,
   ERR_HELPNOTFOUND         = 524,
-  RPL_LOGON                = 600,
-  RPL_LOGOFF               = 601,
-  RPL_WATCHOFF             = 602,
-  RPL_WATCHSTAT            = 603,
-  RPL_NOWON                = 604,
-  RPL_NOWOFF               = 605,
-  RPL_WATCHLIST            = 606,
-  RPL_ENDOFWATCHLIST       = 607,
   RPL_WHOISSECURE          = 671,
   RPL_MODLIST              = 702,
   RPL_ENDOFMODLIST         = 703,
@@ -246,6 +239,11 @@ enum irc_numerics
   RPL_TARGNOTIFY           = 717,
   RPL_UMODEGMSG            = 718,
   ERR_NOPRIVS              = 723,
+  RPL_MONONLINE            = 730,
+  RPL_MONOFFLINE           = 731,
+  RPL_MONLIST              = 732,
+  RPL_ENDOFMONLIST         = 733,
+  ERR_MONLISTFULL          = 734,
   ERR_INVALIDBAN           = 743,
   RPL_ETRACEEND            = 759,
   ERR_LAST_ERR_MSG         = 999
