@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file server.h
  * \brief A header for the server functions.
- * \version $Id: server.h 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: server.h 9858 2021-01-01 04:43:42Z michael $
  */
 
 #ifndef INCLUDED_server_h
@@ -47,7 +47,7 @@ struct server_hunt
 };
 
 extern bool server_valid_name(const char *);
-extern const struct server_hunt *server_hunt(struct Client *, const char *, const int, const int, char *[]);
+extern const struct server_hunt *server_hunt(struct Client *, const char *, const int, char *[]);
 extern void write_links_file(void *);
 extern void read_links_file(void);
 extern void try_connections(void *);
