@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file whowas.h
  * \brief A header for the whowas functions.
- * \version $Id: whowas.h 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: whowas.h 9858 2021-01-01 04:43:42Z michael $
  */
 
 #ifndef INCLUDED_whowas_h
@@ -33,9 +33,9 @@
 
 struct Whowas
 {
-  dlink_node hnode;  /**< List node; linked into whowas_hash */
-  dlink_node cnode;  /**< List node; linked into client->whowas_list */
-  dlink_node lnode;  /**< List node; linked into whowas_list */
+  dlink_node hash_node;  /**< List node; linked into whowas_hash */
+  dlink_node list_node;  /**< List node; linked into whowas_list */
+  dlink_node client_list_node;  /**< List node; linked into client->whowas_list */
   unsigned int hash_value;  /**< Hash value derived from Whowas::name */
   uintmax_t logoff;  /**< When the client logged off; real time */
   bool server_hidden;  /**< Client's server is hidden */
@@ -47,7 +47,7 @@ struct Whowas
   char sockhost[HOSTIPLEN + 1];  /**< Client's IP address as string */
   char realname[REALLEN + 1];  /**< Client's real name/gecos */
   char servername[HOSTLEN + 1];  /**< Name of the server the client is using */
-  struct Client *online;  /**< Pointer to new nick name for chasing or NULL */
+  struct Client *client;  /**< Pointer to new nick name for chasing or NULL */
 };
 
 extern const dlink_list *whowas_get_hash(unsigned int);
