@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_bmask.c
  * \brief Includes required functions for processing the BMASK command.
- * \version $Id: m_bmask.c 9347 2020-04-25 17:00:41Z michael $
+ * \version $Id: m_bmask.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -58,7 +58,6 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
   char modebuf[IRCD_BUFSIZE] = "";
   char parabuf[IRCD_BUFSIZE] = "";
   char banbuf[IRCD_BUFSIZE] = "";
-  struct Channel *channel = NULL;
   const char *mask;
   char *s, *t, *mbuf, *pbuf;
   dlink_list *list = NULL;
@@ -66,10 +65,11 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
   int modecount = 0;
   unsigned int flags = 0, type = 0;
 
-  if ((channel = hash_find_channel(parv[2])) == NULL)
+  struct Channel *channel = hash_find_channel(parv[2]);
+  if (channel == NULL)
     return;
 
-  /* TS is higher, drop it. */
+  /* Their TS is higher, drop it. */
   if (strtoumax(parv[1], NULL, 10) > channel->creation_time)
     return;
 
@@ -152,13 +152,11 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
 static struct Message bmask_msgtab =
 {
   .cmd = "BMASK",
-  .args_min = 5,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_ignore,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_bmask,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_ignore },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_bmask, .args_min = 5 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -175,7 +173,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9347 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
