@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_error.c
  * \brief Includes required functions for processing the ERROR command.
- * \version $Id: m_error.c 9364 2020-04-30 19:24:10Z michael $
+ * \version $Id: m_error.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -54,7 +54,7 @@ mr_error(struct Client *source_p, int parc, char *parv[])
     return;
 
   const char *message = "<>";
-  if (parc > 1 && !EmptyString(parv[1]))
+  if (!EmptyString(parv[1]))
     message = parv[1];
 
   ilog(LOG_TYPE_IRCD, "Received ERROR message from %s: %s",
@@ -83,7 +83,7 @@ static void
 ms_error(struct Client *source_p, int parc, char *parv[])
 {
   const char *message = "<>";
-  if (parc > 1 && !EmptyString(parv[1]))
+  if (!EmptyString(parv[1]))
     message = parv[1];
 
   ilog(LOG_TYPE_IRCD, "Received ERROR message from %s: %s",
@@ -103,12 +103,11 @@ ms_error(struct Client *source_p, int parc, char *parv[])
 static struct Message error_msgtab =
 {
   .cmd = "ERROR",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = mr_error,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_error,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = mr_error },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_error },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -125,7 +124,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9364 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
