@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_mode.c
  * \brief Includes required functions for processing the MODE command.
- * \version $Id: m_mode.c 9364 2020-04-30 19:24:10Z michael $
+ * \version $Id: m_mode.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -55,11 +55,11 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
 {
   const struct user_modes *tab = NULL;
   const unsigned int setmodes = source_p->umodes;
-  const struct Client *target_p = NULL;
   bool badmode = false;
   int what = MODE_ADD;
 
-  if ((target_p = find_person(source_p, parv[1])) == NULL)
+  const struct Client *target_p = find_person(source_p, parv[1]);
+  if (target_p == NULL)
   {
     if (MyConnect(source_p))
       sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, parv[1]);
@@ -117,15 +117,14 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
 
           if (MyConnect(source_p))
           {
-            dlink_node *node;
-
             svstag_detach(&source_p->svstags, RPL_WHOISOPERATOR);
             conf_detach(source_p, CONF_OPER);
 
             ClrOFlag(source_p);
             DelUMode(source_p, ConfigGeneral.oper_only_umodes);
 
-            if ((node = dlinkFindDelete(&oper_list, source_p)))
+            dlink_node *node = dlinkFindDelete(&oper_list, source_p);
+            if (node)
               free_dlink_node(node);
           }
         }
@@ -195,12 +194,6 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
 static void
 m_mode(struct Client *source_p, int parc, char *parv[])
 {
-  if (EmptyString(parv[1]))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "MODE");
-    return;
-  }
-
   /* Now, try to find the channel in question */
   if (!IsChanPrefix(*parv[1]))
   {
@@ -222,7 +215,7 @@ m_mode(struct Client *source_p, int parc, char *parv[])
     char modebuf[MODEBUFLEN] = "";
     char parabuf[MODEBUFLEN] = "";
 
-    channel_modes(channel, source_p, modebuf, parabuf);
+    channel_modes(channel, source_p, NULL, modebuf, parabuf);
     sendto_one_numeric(source_p, &me, RPL_CHANNELMODEIS, channel->name, modebuf, parabuf);
     sendto_one_numeric(source_p, &me, RPL_CREATIONTIME, channel->name, channel->creation_time);
     return;
@@ -230,7 +223,7 @@ m_mode(struct Client *source_p, int parc, char *parv[])
 
   struct ChannelMember *member = NULL;
   if (MyClient(source_p))
-    member = find_channel_link(source_p, channel);
+    member = member_find_link(source_p, channel);
 
   channel_mode_set(source_p, channel, member, parc - 2, parv + 2);
 }
@@ -238,13 +231,11 @@ m_mode(struct Client *source_p, int parc, char *parv[])
 static struct Message mode_msgtab =
 {
   .cmd = "MODE",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_mode,
-  .handlers[SERVER_HANDLER] = m_mode,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_mode
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_mode, .args_min = 2 },
+  .handlers[SERVER_HANDLER] = { .handler = m_mode, .args_min = 2 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_mode, .args_min = 2 }
 };
 
 static void
@@ -261,7 +252,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9364 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
