@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id$
+ * \version $Id: m_nick.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -342,17 +342,14 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   client_p->hopcount = atoi(parv[2]);
   client_p->tsinfo = strtoumax(parv[3], NULL, 10);
 
-  /* TBR: compatibility mode */
-  const int does_rhost = parc == 12;
-
   strlcpy(client_p->name, parv[1], sizeof(client_p->name));
   strlcpy(client_p->username, parv[5], sizeof(client_p->username));
   strlcpy(client_p->host, parv[6], sizeof(client_p->host));
-  strlcpy(client_p->realhost, parv[6 + does_rhost], sizeof(client_p->realhost));
-  strlcpy(client_p->sockhost, parv[7 + does_rhost], sizeof(client_p->sockhost));
-  strlcpy(client_p->id, parv[8 + does_rhost], sizeof(client_p->id));
-  strlcpy(client_p->account, parv[9 + does_rhost], sizeof(client_p->account));
-  strlcpy(client_p->info, parv[parc - 1], sizeof(client_p->info));
+  strlcpy(client_p->realhost, parv[7], sizeof(client_p->realhost));
+  strlcpy(client_p->sockhost, parv[8], sizeof(client_p->sockhost));
+  strlcpy(client_p->id, parv[9], sizeof(client_p->id));
+  strlcpy(client_p->account, parv[10], sizeof(client_p->account));
+  strlcpy(client_p->info, parv[11], sizeof(client_p->info));
 
   struct addrinfo hints, *res;
   memset(&hints, 0, sizeof(hints));
@@ -419,9 +416,7 @@ static bool
 perform_uid_introduction_collides(struct Client *source_p, struct Client *target_p,
                                   int parc, char *parv[])
 {
-  /* TBR: compatibility mode */
-  const int does_rhost = parc == 12;
-  const char *uid = parv[8 + does_rhost];
+  const char *uid = parv[9];
   uintmax_t newts = strtoumax(parv[3], NULL, 10);
 
   assert(IsServer(source_p));
@@ -452,7 +447,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
 
   /* The timestamps are different */
   bool sameuser = irccmp(target_p->username, parv[5]) == 0 &&
-                  irccmp(target_p->sockhost, parv[7 + does_rhost]) == 0;
+                  irccmp(target_p->sockhost, parv[8]) == 0;
 
   /*
    * If the users are the same (loaded a client on a different server)
@@ -798,17 +793,11 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
 static void
 ms_uid(struct Client *source_p, int parc, char *parv[])
 {
-/* TBR: compatibility mode */
-  const int does_rhost = parc == 12;
-
   if (check_clean_nick(source_p, parv[1]) == false ||
       check_clean_user(source_p, parv[1], parv[5]) == false ||
       check_clean_host(source_p, parv[1], parv[6]) == false ||
-      check_clean_uid(source_p, parv[1], parv[8 + does_rhost]) == false)
-    return;
-
-  /* TBR: compatibility mode */
-  if (does_rhost && check_clean_host(source_p, parv[1], parv[7]) == false)
+      check_clean_host(source_p, parv[1], parv[7]) == false ||
+      check_clean_uid(source_p, parv[1], parv[9]) == false)
     return;
 
   /*
@@ -816,7 +805,7 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
    * This may generate 401's, but it ensures that both clients always
    * go, even if the other server refuses to do the right thing.
    */
-  struct Client *target_p = hash_find_id(parv[8 + does_rhost]);
+  struct Client *target_p = hash_find_id(parv[9]);
   if (target_p)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
@@ -860,7 +849,7 @@ static struct Message uid_msgtab =
   .cmd = "UID",
   .handlers[UNREGISTERED_HANDLER] = { .handler = m_ignore },
   .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
-  .handlers[SERVER_HANDLER] = { .handler = ms_uid, .args_min = 11 },
+  .handlers[SERVER_HANDLER] = { .handler = ms_uid, .args_min = 12 },
   .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
   .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
@@ -881,7 +870,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision$",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
