@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_server.c
  * \brief Includes required functions for processing the SERVER/SID command.
- * \version $Id: m_server.c 9360 2020-04-29 14:02:24Z michael $
+ * \version $Id: m_server.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -36,6 +36,7 @@
 #include "numeric.h"
 #include "conf.h"
 #include "conf_service.h"
+#include "listener.h"
 #include "log.h"
 #include "misc.h"
 #include "server.h"
@@ -130,26 +131,16 @@ server_send_client(struct Client *client_p, struct Client *target_p)
     buf[1] = '\0';
   }
 
-    /* TBR: compatibility mode */
-  if (IsCapable(client_p, CAPAB_RHOST))
-    sendto_one(client_p, ":%s UID %s %u %ju %s %s %s %s %s %s %s :%s",
-               target_p->servptr->id,
-               target_p->name, target_p->hopcount + 1,
-               target_p->tsinfo,
-               buf, target_p->username, target_p->host, target_p->realhost,
-               target_p->sockhost, target_p->id,
-               target_p->account, target_p->info);
-  else
-    sendto_one(client_p, ":%s UID %s %u %ju %s %s %s %s %s %s :%s",
-               target_p->servptr->id,
-               target_p->name, target_p->hopcount + 1,
-               target_p->tsinfo,
-               buf, target_p->username, target_p->host,
-               target_p->sockhost, target_p->id,
-               target_p->account, target_p->info);
+  sendto_one(client_p, ":%s UID %s %u %ju %s %s %s %s %s %s %s :%s",
+             target_p->servptr->id,
+             target_p->name, target_p->hopcount + 1,
+             target_p->tsinfo,
+             buf, target_p->username, target_p->host, target_p->realhost,
+             target_p->sockhost, target_p->id,
+             target_p->account, target_p->info);
 
-  if (!EmptyString(target_p->certfp))
-    sendto_one(client_p, ":%s CERTFP %s", target_p->id, target_p->certfp);
+  if (!EmptyString(target_p->tls_certfp))
+    sendto_one(client_p, ":%s CERTFP %s", target_p->id, target_p->tls_certfp);
 
   if (target_p->away[0])
     sendto_one(client_p, ":%s AWAY :%s", target_p->id, target_p->away);
@@ -229,15 +220,15 @@ server_estab(struct Client *client_p)
   {
     const struct MaskItem *const conf = client_p->connection->confs.head->data;
 
-    sendto_one(client_p, "PASS %s TS %u %s", conf->spasswd, TS_CURRENT, me.id);
+    sendto_one(client_p, "PASS %s", conf->spasswd);
 
     sendto_one(client_p, "CAPAB :%s", capab_get(NULL));
 
-    sendto_one(client_p, "SERVER %s 1 :%s%s",
-               me.name, ConfigServerHide.hidden ? "(H) " : "", me.info);
+    sendto_one(client_p, "SERVER %s 1 %s +%s :%s",
+               me.name, me.id, ConfigServerHide.hidden ? "h" : "", me.info);
   }
 
-  sendto_one(client_p, ":%s SVINFO %u %u 0 :%ju", me.id, TS_CURRENT, TS_MIN,
+  sendto_one(client_p, ":%s SVINFO %u %u 0 :%ju", me.id, TS_CURRENT, TS_MINIMUM,
              event_base->time.sec_real);
 
   if (IsDead(client_p))
@@ -275,19 +266,21 @@ server_estab(struct Client *client_p)
   /* Show the real host/IP to admins */
   if (tls_isusing(&client_p->connection->fd->tls))
   {
+    client_p->tls_cipher = xstrdup(tls_get_cipher(&client_p->connection->fd->tls));
+
     /* Show the real host/IP to admins */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link with %s established: [TLS: %s] (Capabilities: %s)",
-                         client_get_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd->tls),
+                         client_get_name(client_p, SHOW_IP), client_p->tls_cipher,
                          capab_get(client_p));
 
     /* Now show the masked hostname/IP to opers */
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link with %s established: [TLS: %s] (Capabilities: %s)",
-                         client_get_name(client_p, MASK_IP), tls_get_cipher(&client_p->connection->fd->tls),
+                         client_get_name(client_p, MASK_IP), client_p->tls_cipher,
                          capab_get(client_p));
     ilog(LOG_TYPE_IRCD, "Link with %s established: [TLS: %s] (Capabilities: %s)",
-         client_get_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd->tls),
+         client_get_name(client_p, SHOW_IP), client_p->tls_cipher,
          capab_get(client_p));
   }
   else
@@ -306,9 +299,9 @@ server_estab(struct Client *client_p)
 
   fd_note(client_p->connection->fd, "Server: %s", client_p->name);
 
-  sendto_server(client_p, 0, 0, ":%s SID %s 2 %s :%s%s",
+  sendto_server(client_p, 0, 0, ":%s SID %s 2 %s +%s :%s",
                 me.id, client_p->name, client_p->id,
-                IsHidden(client_p) ? "(H) " : "", client_p->info);
+                IsHidden(client_p) ? "h" : "", client_p->info);
 
   /*
    * Pass on my client information to the new server
@@ -333,9 +326,9 @@ server_estab(struct Client *client_p)
     if (IsMe(target_p) || target_p->from == client_p)
       continue;
 
-    sendto_one(client_p, ":%s SID %s %u %s :%s%s",
+    sendto_one(client_p, ":%s SID %s %u %s +%s :%s",
                target_p->servptr->id, target_p->name, target_p->hopcount+1,
-               target_p->id, IsHidden(target_p) ? "(H) " : "",
+               target_p->id, IsHidden(target_p) ? "h" : "",
                target_p->info);
   }
 
@@ -414,7 +407,7 @@ server_check(const char *name, struct Client *client_p)
         return SERVER_CHECK_INVALID_PASSWORD;
 
       if (!EmptyString(conf->certfp))
-        if (EmptyString(client_p->certfp) || strcasecmp(client_p->certfp, conf->certfp))
+        if (EmptyString(client_p->tls_certfp) || strcasecmp(client_p->tls_certfp, conf->certfp))
           return SERVER_CHECK_INVALID_CERTIFICATE;
 
       conf_attach(client_p, conf);
@@ -447,9 +440,9 @@ mr_server(struct Client *source_p, int parc, char *parv[])
   const char *error = NULL;
   bool warn = true;
 
-  if (EmptyString(parv[parc - 1]))
+  if (listener_has_flag(source_p->connection->listener, LISTENER_CLIENT) == true)
   {
-    exit_client(source_p, "No server description supplied");
+    exit_client(source_p, "Use a different port");
     return;
   }
 
@@ -526,10 +519,11 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  struct Client *target_p;
-  if ((target_p = hash_find_server(name)))
+  struct Client *target_p = hash_find_server(name);
+  if (target_p)
   {
-    /* This link is trying feed me a server that I already have
+    /*
+     * This link is trying feed me a server that I already have
      * access through another path -- multiple paths not accepted
      * currently, kill this link immediately!!
      *
@@ -549,7 +543,8 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  if ((target_p = hash_find_id(source_p->id)))
+  target_p = hash_find_id(source_p->id);
+  if (target_p)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Attempt to re-introduce server %s SID %s from %s",
@@ -567,12 +562,13 @@ mr_server(struct Client *source_p, int parc, char *parv[])
    * a connect comes in with same name toss the pending one,
    * but only if it's not the same client! - Dianora
    */
-  if ((target_p = find_servconn_in_progress(name)))
-    if (target_p != source_p)
-      exit_client(target_p, "Overridden");
+  target_p = find_servconn_in_progress(name);
+  if (target_p && (target_p != source_p))
+    exit_client(target_p, "Overridden");
 
-  /* if we are connecting (Handshake), we already have the name from the
-   * connect{} block in source_p->name
+  /*
+   * If we are connecting (Handshake), we already have the name from the
+   * connect{} block in source_p->name.
    */
   strlcpy(source_p->name, name, sizeof(source_p->name));
 
@@ -611,12 +607,6 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   if (!IsServer(source_p))
     return;
 
-  if (EmptyString(parv[parc - 1]))
-  {
-    exit_client(source_p->from, "No server description supplied");
-    return;
-  }
-
   if (server_valid_name(parv[1]) == false)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
@@ -641,9 +631,9 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  /* collision on SID? */
-  struct Client *target_p;
-  if ((target_p = hash_find_id(parv[3])))
+  /* Collision on SID? */
+  struct Client *target_p = hash_find_id(parv[3]);
+  if (target_p)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s cancelled, server ID %s already exists",
@@ -655,8 +645,9 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  /* collision on name? */
-  if ((target_p = hash_find_server(parv[1])))
+  /* Collision on name? */
+  target_p = hash_find_server(parv[1]);
+  if (target_p)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s cancelled, server %s already exists",
@@ -672,9 +663,9 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
    * a connect comes in with same name toss the pending one,
    * but only if it's not the same client! - Dianora
    */
-  if ((target_p = find_servconn_in_progress(parv[1])))
-    if (target_p != source_p->from)
-      exit_client(target_p, "Overridden");
+  target_p = find_servconn_in_progress(parv[1]);
+  if (target_p && (target_p != source_p->from))
+    exit_client(target_p, "Overridden");
 
   /*
    * See if the newly found server is behind a guaranteed
@@ -703,14 +694,15 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  /* Ok, this way this works is
+  /*
+   * Ok, this way this works is
    *
    * A server can have a CONF_HUB allowing it to introduce servers
    * behind it.
    *
    * connect {
    *            name = "irc.bighub.net";
-   *            hub_mask="*";
+   *            hub_mask = "*";
    *            ...
    *
    * That would allow "irc.bighub.net" to introduce anything it wanted..
@@ -719,11 +711,11 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
    *
    * connect {
    *            name = "irc.somehub.fi";
-   *		hub_mask="*";
-   *		leaf_mask="*.edu";
-   *...
-   * Would allow this server in finland to hub anything but
-   * .edu's
+   *            hub_mask = "*";
+   *            leaf_mask = "*.edu";
+   *            ...
+   *
+   * Would allow this server in finland to hub anything but .edu's
    */
 
   /* Ok, check source_p->from can hub the new server */
@@ -781,9 +773,9 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   hash_add_client(target_p);
   hash_add_id(target_p);
 
-  sendto_server(source_p->from, 0, 0, ":%s SID %s %u %s :%s%s",
+  sendto_server(source_p->from, 0, 0, ":%s SID %s %u %s +%s :%s",
                 source_p->id, target_p->name, target_p->hopcount + 1,
-                target_p->id, IsHidden(target_p) ? "(H) " : "", target_p->info);
+                target_p->id, IsHidden(target_p) ? "h" : "", target_p->info);
   sendto_realops_flags(UMODE_EXTERNAL, L_ALL, SEND_NOTICE,
                        "Server %s being introduced by %s",
                        target_p->name, source_p->name);
@@ -792,25 +784,21 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
 static struct Message server_msgtab =
 {
   .cmd = "SERVER",
-  .args_min = 4,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = mr_server,
-  .handlers[CLIENT_HANDLER] = m_registered,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_registered
+  .handlers[UNREGISTERED_HANDLER] = { .handler = mr_server, .args_min = 4 },
+  .handlers[CLIENT_HANDLER] = { .handler = m_registered },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_registered }
 };
 
 static struct Message sid_msgtab =
 {
   .cmd = "SID",
-  .args_min = 5,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_ignore,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_sid,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_ignore },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_sid, .args_min = 5 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -829,7 +817,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9360 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
