@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_sjoin.c
  * \brief Includes required functions for processing the SJOIN command.
- * \version $Id: m_sjoin.c 9288 2020-02-23 08:38:34Z michael $
+ * \version $Id: m_sjoin.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -42,11 +42,152 @@
 #include "misc.h"
 
 
-static void set_final_mode(struct Mode *, struct Mode *, char *, char *);
-static void remove_our_modes(struct Channel *, struct Client *);
-static void remove_a_mode(struct Channel *, struct Client *, int, char);
-static void remove_ban_list(struct Channel *, struct Client *, dlink_list *, char);
+/* set_final_mode
+ *
+ * inputs	- channel mode
+ *		- old channel mode
+ * output	- NONE
+ * side effects	- walk through all the channel modes turning off modes
+ *		  that were on in oldmode but aren't on in mode.
+ *		  Then walk through turning on modes that are on in mode
+ *		  but were not set in oldmode.
+ */
+static void
+set_final_mode(const struct Mode *mode, const struct Mode *oldmode, char *mbuf, char *pbuf)
+{
+  int what = MODE_QUERY;
 
+  for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
+  {
+    if (tab->mode && (tab->mode & mode->mode) && !(tab->mode & oldmode->mode))
+    {
+      if (what != MODE_ADD)
+      {
+        *mbuf++ = '+';
+        what = MODE_ADD;
+      }
+
+      *mbuf++ = tab->letter;
+    }
+  }
+
+  for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
+  {
+    if (tab->mode && (tab->mode & oldmode->mode) && !(tab->mode & mode->mode))
+    {
+      if (what != MODE_DEL)
+      {
+        *mbuf++ = '-';
+        what = MODE_DEL;
+      }
+
+      *mbuf++ = tab->letter;
+    }
+  }
+
+  if (oldmode->limit && mode->limit == 0)
+  {
+    if (what != MODE_DEL)
+    {
+      *mbuf++ = '-';
+      what = MODE_DEL;
+    }
+
+    *mbuf++ = 'l';
+  }
+
+  if (oldmode->key[0] && mode->key[0] == '\0')
+  {
+    if (what != MODE_DEL)
+    {
+      *mbuf++ = '-';
+      what = MODE_DEL;
+    }
+
+    *mbuf++ = 'k';
+    pbuf += sprintf(pbuf, "%s ", oldmode->key);
+  }
+
+  if (mode->limit && oldmode->limit != mode->limit)
+  {
+    if (what != MODE_ADD)
+    {
+      *mbuf++ = '+';
+      what = MODE_ADD;
+    }
+
+    *mbuf++ = 'l';
+    pbuf += sprintf(pbuf, "%u ", mode->limit);
+  }
+
+  if (mode->key[0] && strcmp(oldmode->key, mode->key))
+  {
+    if (what != MODE_ADD)
+    {
+      *mbuf++ = '+';
+      what = MODE_ADD;
+    }
+
+    *mbuf++ = 'k';
+    pbuf += sprintf(pbuf, "%s ", mode->key);
+  }
+
+  *mbuf = '\0';
+}
+
+/* remove_ban_list()
+ *
+ * inputs	- channel, source, list to remove, char of mode
+ * outputs	- none
+ * side effects	- given ban list is removed, modes are sent to local clients
+ */
+static void
+remove_ban_list(struct Channel *channel, const struct Client *client, dlink_list *list, char c)
+{
+  char modebuf[IRCD_BUFSIZE];
+  char parabuf[IRCD_BUFSIZE];
+  char *mbuf;
+  char *pbuf;
+  int count = 0;
+  int cur_len, mlen;
+
+  if (dlink_list_length(list) == 0)
+    return;
+
+  cur_len = mlen = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s -",
+                            client->name, channel->name);
+  mbuf = modebuf + mlen;
+  pbuf = parabuf;
+
+  while (list->head)
+  {
+    struct Ban *ban = list->head->data;
+    int plen = ban->banstr_len + 2;  /* +2 = b and space */
+
+    if (count >= MAXMODEPARAMS ||
+        (cur_len + 1 /* space between */ + (plen - 1)) > IRCD_BUFSIZE - 2)
+    {
+      /* NUL-terminate and remove trailing space */
+      *mbuf = *(pbuf - 1) = '\0';
+      sendto_channel_local(NULL, channel, 0, 0, 0, "%s %s", modebuf, parabuf);
+
+      cur_len = mlen;
+      mbuf = modebuf + mlen;
+      pbuf = parabuf;
+      count = 0;
+    }
+
+    *mbuf++ = c;
+    cur_len += plen;
+    pbuf += sprintf(pbuf, "%s ", ban->banstr);
+    ++count;
+
+    remove_ban(ban, list);
+  }
+
+  *mbuf = *(pbuf - 1) = '\0';
+  sendto_channel_local(NULL, channel, 0, 0, 0, "%s %s", modebuf, parabuf);
+}
 
 /* ms_sjoin()
  *
@@ -63,11 +204,8 @@ static void remove_ban_list(struct Channel *, struct Client *, dlink_list *, cha
 static void
 ms_sjoin(struct Client *source_p, int parc, char *parv[])
 {
-  struct Channel *channel = NULL;
   struct Client  *target_p = NULL;
-  uintmax_t newts;
-  uintmax_t oldts;
-  struct Mode mode, *oldmode;
+  struct Mode mode = { .mode = 0, .limit = 0, .key[0] = '\0' };
   int            args = 0;
   bool           isnew = false;
   bool           keep_our_modes = true;
@@ -85,8 +223,6 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   char uid_buf[IRCD_BUFSIZE];  /* buffer for modes/prefixes */
   char           *uid_ptr;
   char           *p; /* pointer used making sjbuf */
-  const char *servername = (ConfigServerHide.hide_servers || IsHidden(source_p)) ?
-                            me.name : source_p->name;
   const char *para[MAXMODEPARAMS];
   char sendbuf[MODEBUFLEN] = "";
   char modebuf[MODEBUFLEN] = "";
@@ -104,13 +240,6 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  pargs = 0;
-  newts = strtoumax(parv[1], NULL, 10);
-
-  mode.mode = 0;
-  mode.limit = 0;
-  mode.key[0] = '\0';
-
   for (const char *modes = parv[3]; *modes; ++modes)
   {
     switch (*modes)
@@ -142,14 +271,15 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  if ((channel = hash_find_channel(parv[2])) == NULL)
+  struct Channel *channel = hash_find_channel(parv[2]);
+  if (channel == NULL)
   {
     isnew = true;
     channel = channel_make(parv[2]);
   }
 
-  oldts = channel->creation_time;
-  oldmode = &channel->mode;
+  uintmax_t newts = strtoumax(parv[1], NULL, 10);
+  uintmax_t oldts = channel->creation_time;
 
   if (newts == 0 && isnew == false && oldts)
   {
@@ -175,6 +305,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   else
     keep_new_modes = false;
 
+  struct Mode *oldmode = &channel->mode;
+
   if (keep_new_modes == false)
     mode = *oldmode;
   else if (keep_our_modes == true)
@@ -190,6 +322,10 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   set_final_mode(&mode, oldmode, modebuf, parabuf);
   channel->mode = mode;
 
+  const struct Client *origin = source_p;
+  if (IsHidden(source_p) || ConfigServerHide.hide_servers)
+    origin = &me;
+
   /* Lost the TS, other side wins, so remove modes on this side */
   if (keep_our_modes == false)
   {
@@ -197,11 +333,13 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     if (isnew == false)
       strlcpy(channel->name, parv[2], sizeof(channel->name));
 
-    remove_our_modes(channel, source_p);
+    channel_demote_members(channel, origin, CHFL_CHANOP, 'o');
+    channel_demote_members(channel, origin, CHFL_HALFOP, 'h');
+    channel_demote_members(channel, origin, CHFL_VOICE, 'v');
 
-    remove_ban_list(channel, source_p, &channel->banlist, 'b');
-    remove_ban_list(channel, source_p, &channel->exceptlist, 'e');
-    remove_ban_list(channel, source_p, &channel->invexlist, 'I');
+    remove_ban_list(channel, origin, &channel->banlist, 'b');
+    remove_ban_list(channel, origin, &channel->exceptlist, 'e');
+    remove_ban_list(channel, origin, &channel->invexlist, 'I');
 
     clear_ban_cache_list(&channel->members_local);
     invite_clear_list(&channel->invites);
@@ -210,9 +348,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     {
       channel_set_topic(channel, "", "", 0, false);
       sendto_channel_local(NULL, channel, 0, 0, 0, ":%s TOPIC %s :",
-                           (IsHidden(source_p) ||
-                           ConfigServerHide.hide_servers) ?
-                           me.name : source_p->name, channel->name);
+                           origin->name, channel->name);
     }
 
     sendto_channel_local(NULL, channel, 0, 0, 0,
@@ -222,15 +358,11 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   }
 
   if (*modebuf)
-  {
-    /* This _SHOULD_ be to ALL_MEMBERS
-     * It contains only +imnpstlk, etc */
     sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s %s",
-                         servername, channel->name, modebuf, parabuf);
-  }
+                         origin->name, channel->name, modebuf, parabuf);
 
   if (*parv[3] != '0' && keep_new_modes == true)
-    channel_modes(channel, source_p, modebuf, parabuf);
+    channel_modes(channel, source_p, NULL, modebuf, parabuf);
   else
   {
     modebuf[0] = '0';
@@ -346,7 +478,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
 
     uid_ptr += sprintf(uid_ptr, "%s%s ", uid_prefix, target_p->id);
 
-    if (!IsMember(target_p, channel))
+    if (member_find_link(target_p, channel) == NULL)
     {
       add_user_to_channel(channel, target_p, fl, have_many_uids == false);
 
@@ -390,7 +522,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
         }
 
         sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
-                             servername, channel->name, modebuf, sendbuf);
+                             origin->name, channel->name, modebuf, sendbuf);
         mbuf = modebuf;
         *mbuf++ = '+';
 
@@ -416,7 +548,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
         }
 
         sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
-                             servername, channel->name, modebuf, sendbuf);
+                             origin->name, channel->name, modebuf, sendbuf);
 
         mbuf = modebuf;
         *mbuf++ = '+';
@@ -443,7 +575,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
         }
 
         sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
-                             servername, channel->name, modebuf, sendbuf);
+                             origin->name, channel->name, modebuf, sendbuf);
 
         mbuf = modebuf;
         *mbuf++ = '+';
@@ -491,7 +623,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     }
 
     sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
-                         servername, channel->name, modebuf, sendbuf);
+                         origin->name, channel->name, modebuf, sendbuf);
   }
 
   /*
@@ -513,223 +645,14 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   sendto_server(source_p, 0, 0, "%s", uid_buf);
 }
 
-/* set_final_mode
- *
- * inputs	- channel mode
- *		- old channel mode
- * output	- NONE
- * side effects	- walk through all the channel modes turning off modes
- *		  that were on in oldmode but aren't on in mode.
- *		  Then walk through turning on modes that are on in mode
- *		  but were not set in oldmode.
- */
-static void
-set_final_mode(struct Mode *mode, struct Mode *oldmode, char *mbuf, char *pbuf)
-{
-  int len = 0;
-
-  *mbuf++ = '-';
-
-  for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
-    if (tab->mode && (tab->mode & oldmode->mode) && !(tab->mode & mode->mode))
-      *mbuf++ = tab->letter;
-
-  if (oldmode->limit && mode->limit == 0)
-    *mbuf++ = 'l';
-
-  if (oldmode->key[0] && mode->key[0] == '\0')
-  {
-    *mbuf++ = 'k';
-    len = sprintf(pbuf, "%s ", oldmode->key);
-    pbuf += len;
-  }
-
-  if (*(mbuf - 1) == '-')
-    *(mbuf - 1) = '+';
-  else
-    *mbuf++ = '+';
-
-  for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
-    if (tab->mode && (tab->mode & mode->mode) && !(tab->mode & oldmode->mode))
-      *mbuf++ = tab->letter;
-
-  if (mode->limit && oldmode->limit != mode->limit)
-  {
-    *mbuf++ = 'l';
-    len = sprintf(pbuf, "%u ", mode->limit);
-    pbuf += len;
-  }
-
-  if (mode->key[0] && strcmp(oldmode->key, mode->key))
-  {
-    *mbuf++ = 'k';
-    len = sprintf(pbuf, "%s ", mode->key);
-    pbuf += len;
-  }
-
-  if (*(mbuf - 1) == '+')
-    *(mbuf - 1) = '\0';
-  else
-    *mbuf = '\0';
-}
-
-/* remove_our_modes()
- *
- * inputs	- pointer to channel to remove modes from
- *		- client pointer
- * output	- NONE
- * side effects	- Go through the local members, remove all their
- *		  chanop modes etc., this side lost the TS.
- */
-static void
-remove_our_modes(struct Channel *channel, struct Client *source_p)
-{
-  remove_a_mode(channel, source_p, CHFL_CHANOP, 'o');
-  remove_a_mode(channel, source_p, CHFL_HALFOP, 'h');
-  remove_a_mode(channel, source_p, CHFL_VOICE, 'v');
-}
-
-/* remove_a_mode()
- *
- * inputs	- pointer to channel
- *		- server or client removing the mode
- *		- mask o/h/v mask to be removed
- *		- flag o/h/v to be removed
- * output	- NONE
- * side effects	- remove ONE mode from all members of a channel
- */
-static void
-remove_a_mode(struct Channel *channel, struct Client *source_p,
-             int mask, char flag)
-{
-  dlink_node *node = NULL;
-  char lmodebuf[MODEBUFLEN];
-  char sendbuf[MODEBUFLEN];
-  char *sp = sendbuf;
-  const char *lpara[MAXMODEPARAMS];
-  unsigned int count = 0;
-  int l = 0;
-  char *mbuf = lmodebuf;
-
-  *mbuf++ = '-';
-  *sp = '\0';
-
-  DLINK_FOREACH(node, channel->members.head)
-  {
-    struct ChannelMember *member = node->data;
-
-    if ((member->flags & mask) == 0)
-      continue;
-
-    member->flags &= ~mask;
-
-    lpara[count++] = member->client->name;
-
-    *mbuf++ = flag;
-
-    if (count >= MAXMODEPARAMS)
-    {
-      for (unsigned int i = 0; i < MAXMODEPARAMS; ++i)
-      {
-        l = sprintf(sp, " %s", lpara[i]);
-        sp += l;
-      }
-
-      *mbuf = '\0';
-      sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
-                           (IsHidden(source_p) || ConfigServerHide.hide_servers) ?
-                           me.name : source_p->name,
-                           channel->name, lmodebuf, sendbuf);
-      mbuf = lmodebuf;
-      *mbuf++ = '-';
-      count = 0;
-      sp = sendbuf;
-      *sp = '\0';
-    }
-  }
-
-  if (count)
-  {
-    *mbuf = '\0';
-
-    for (unsigned int i = 0; i < count; ++i)
-    {
-      l = sprintf(sp, " %s", lpara[i]);
-      sp += l;
-    }
-
-    sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
-                         (IsHidden(source_p) || ConfigServerHide.hide_servers) ?
-                         me.name : source_p->name,
-                         channel->name, lmodebuf, sendbuf);
-  }
-}
-
-/* remove_ban_list()
- *
- * inputs	- channel, source, list to remove, char of mode
- * outputs	- none
- * side effects	- given ban list is removed, modes are sent to local clients
- */
-static void
-remove_ban_list(struct Channel *channel, struct Client *source_p, dlink_list *list, char c)
-{
-  dlink_node *node, *node_next;
-  char modebuf[IRCD_BUFSIZE];
-  char parabuf[IRCD_BUFSIZE];
-  char *mbuf;
-  char *pbuf;
-  int count = 0;
-  int cur_len, mlen;
-
-  if (dlink_list_length(list) == 0)
-    return;
-
-  cur_len = mlen = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s -",
-                            source_p->name, channel->name);
-  mbuf = modebuf + mlen;
-  pbuf = parabuf;
-
-  DLINK_FOREACH_SAFE(node, node_next, list->head)
-  {
-    struct Ban *ban = node->data;
-    int plen = ban->banstr_len + 2;  /* +2 = b and space */
-
-    if (count >= MAXMODEPARAMS ||
-        (cur_len + 1 /* space between */ + (plen - 1)) > IRCD_BUFSIZE - 2)
-    {
-      /* NUL-terminate and remove trailing space */
-      *mbuf = *(pbuf - 1) = '\0';
-      sendto_channel_local(NULL, channel, 0, 0, 0, "%s %s", modebuf, parabuf);
-
-      cur_len = mlen;
-      mbuf = modebuf + mlen;
-      pbuf = parabuf;
-      count = 0;
-    }
-
-    *mbuf++ = c;
-    cur_len += plen;
-    pbuf += sprintf(pbuf, "%s ", ban->banstr);
-    ++count;
-
-    remove_ban(ban, list);
-  }
-
-  *mbuf = *(pbuf - 1) = '\0';
-  sendto_channel_local(NULL, channel, 0, 0, 0, "%s %s", modebuf, parabuf);
-}
-
 static struct Message sjoin_msgtab =
 {
   .cmd = "SJOIN",
-  .args_min = 5,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_sjoin,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_sjoin, .args_min = 5, .empty_last_arg = true },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -746,7 +669,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9288 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
