@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2013-2020 ircd-hybrid development team
+ *  Copyright (c) 2013-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_certfp.c
  * \brief Includes required functions for processing the CERTFP command.
- * \version $Id: m_certfp.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_certfp.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -50,23 +50,21 @@ ms_certfp(struct Client *source_p, int parc, char *parv[])
   if (!IsClient(source_p))
     return;
 
-  xfree(source_p->certfp);
-  source_p->certfp = xstrdup(parv[1]);
+  xfree(source_p->tls_certfp);
+  source_p->tls_certfp = xstrdup(parv[1]);
 
   sendto_server(source_p, 0, 0, ":%s CERTFP %s",
-                source_p->id, source_p->certfp);
+                source_p->id, source_p->tls_certfp);
 }
 
 static struct Message certfp_msgtab =
 {
   .cmd = "CERTFP",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_ignore,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_certfp,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_ignore },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_certfp, .args_min = 2 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -83,7 +81,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
