@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_close.c
  * \brief Includes required functions for processing the CLOSE command.
- * \version $Id: m_close.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_close.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -47,18 +47,16 @@
 static void
 mo_close(struct Client *source_p, int parc, char *parv[])
 {
-  dlink_node *node, *node_next;
-  unsigned int closed = dlink_list_length(&unknown_list);
-
   if (!HasOFlag(source_p, OPER_FLAG_CLOSE))
   {
     sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "close");
     return;
   }
 
-  DLINK_FOREACH_SAFE(node, node_next, unknown_list.head)
+  const unsigned int closed = dlink_list_length(&unknown_list);
+  while (unknown_list.head)
   {
-    struct Client *target_p = node->data;
+    struct Client *target_p = unknown_list.head->data;
 
     sendto_one_numeric(source_p, &me, RPL_CLOSING,
                        client_get_name(target_p, SHOW_IP),
@@ -77,12 +75,11 @@ mo_close(struct Client *source_p, int parc, char *parv[])
 static struct Message close_msgtab =
 {
   .cmd = "CLOSE",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_close
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_close }
 };
 
 static void
@@ -99,7 +96,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
