@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2004-2020 ircd-hybrid development team
+ *  Copyright (c) 2004-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_etrace.c
  * \brief Includes required functions for processing the ETRACE command.
- * \version $Id: m_etrace.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_etrace.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -111,10 +111,10 @@ static void
 mo_etrace(struct Client *source_p, int parc, char *parv[])
 {
   if (parc > 2)
-    if (server_hunt(source_p, ":%s ETRACE %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s ETRACE %s :%s", 2, parv)->ret != HUNTED_ISME)
       return;
 
-  const struct server_hunt *hunt = server_hunt(source_p, ":%s ETRACE :%s", 1, parc, parv);
+  const struct server_hunt *hunt = server_hunt(source_p, ":%s ETRACE :%s", 1, parv);
   switch (hunt->ret)
   {
     case HUNTED_PASS:
@@ -132,12 +132,11 @@ mo_etrace(struct Client *source_p, int parc, char *parv[])
 static struct Message etrace_msgtab =
 {
   .cmd = "ETRACE",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = mo_etrace,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_etrace
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = mo_etrace },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_etrace }
 };
 
 static void
@@ -154,7 +153,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
