@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id$
+ * \version $Id: m_info.c 9897 2021-01-17 06:18:18Z michael $
  */
 
 #include "stdinc.h"
@@ -362,10 +362,10 @@ static const struct InfoStruct info_table[] =
     "Inform opers if someone tries to /oper with the wrong credentials"
   },
   {
-    "dots_in_ident",
+    "specials_in_ident",
     OUTPUT_DECIMAL,
-    &ConfigGeneral.dots_in_ident,
-    "Number of permissable dots in an ident"
+    &ConfigGeneral.specials_in_ident,
+    "Number of permissable '-', '_', or '.' characters in an ident"
   },
   {
     "min_nonwildcard",
@@ -556,7 +556,7 @@ static const char *infotext[] =
   "ircd-hybrid --",
   "Based on the original code written by Jarkko Oikarinen",
   "Copyright (c) 1988-1991 University of Oulu, Computing Center",
-  "Copyright (c) 1997-2020 ircd-hybrid development team",
+  "Copyright (c) 1997-2021 ircd-hybrid development team",
   "",
   "This program is free software; you can redistribute it and/or",
   "modify it under the terms of the GNU General Public License as",
@@ -822,7 +822,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision$",
+  .version = "$Revision: 9897 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
