@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_kline.c
  * \brief Includes required functions for processing the KLINE command.
- * \version $Id: m_kline.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_kline.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -50,30 +50,28 @@ kline_check(const struct AddressRec *arec)
 
   DLINK_FOREACH_SAFE(node, node_next, local_client_list.head)
   {
-    struct Client *client_p = node->data;
+    struct Client *client = node->data;
 
-    if (IsDead(client_p))
+    if (IsDead(client))
       continue;
 
-    if (match(arec->username, client_p->username))
+    if (match(arec->username, client->username))
       continue;
 
     switch (arec->masktype)
     {
-      case HM_IPV4:
-        if (client_p->ip.ss.ss_family == AF_INET)
-          if (match_ipv4(&client_p->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
-            conf_try_ban(client_p, CLIENT_BAN_KLINE, arec->conf->reason);
+      case HM_HOST:
+        if (match(arec->Mask.hostname, client->realhost) == 0 ||
+            match(arec->Mask.hostname, client->sockhost) == 0 || match(arec->Mask.hostname, client->host) == 0)
+          conf_try_ban(client, CLIENT_BAN_KLINE, arec->conf->reason);
         break;
       case HM_IPV6:
-        if (client_p->ip.ss.ss_family == AF_INET6)
-          if (match_ipv6(&client_p->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
-            conf_try_ban(client_p, CLIENT_BAN_KLINE, arec->conf->reason);
-        break;
-      default:  /* HM_HOST */
-        if (match(arec->Mask.hostname, client_p->host) == 0 || match(arec->Mask.hostname, client_p->sockhost) == 0)
-          conf_try_ban(client_p, CLIENT_BAN_KLINE, arec->conf->reason);
+      case HM_IPV4:
+        if (address_compare(&client->ip, &arec->Mask.ipa.addr, false, false, arec->Mask.ipa.bits) == true)
+          conf_try_ban(client, CLIENT_BAN_KLINE, arec->conf->reason);
         break;
+      default:
+        assert(0);
     }
   }
 }
@@ -93,9 +91,10 @@ kline_handle(struct Client *source_p, const struct aline_ctx *aline)
 
   if (!HasFlag(source_p, FLAGS_SERVICE) && valid_wild_card(2, aline->user, aline->host) == false)
   {
-    sendto_one_notice(source_p, &me,
-                      ":Please include at least %u non-wildcard characters with the mask",
-                      ConfigGeneral.min_nonwildcard);
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me,
+                        ":Please include at least %u non-wildcard characters with the mask",
+                        ConfigGeneral.min_nonwildcard);
     return;
   }
 
@@ -252,9 +251,6 @@ ms_kline(struct Client *source_p, int parc, char *parv[])
     .duration = strtoumax(parv[2], NULL, 10)
   };
 
-  if (parc != 6 || EmptyString(parv[parc - 1]))
-    return;
-
   sendto_match_servs(source_p, aline.server, CAPAB_KLN, "KLINE %s %ju %s %s :%s", aline.server,
                      aline.duration, aline.user, aline.host, aline.reason);
 
@@ -270,13 +266,11 @@ ms_kline(struct Client *source_p, int parc, char *parv[])
 static struct Message kline_msgtab =
 {
   .cmd = "KLINE",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_kline,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_kline
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_kline, .args_min = 6 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_kline, .args_min = 2 }
 };
 
 static void
@@ -295,7 +289,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
