@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_locops.c
  * \brief Includes required functions for processing the LOCOPS command.
- * \version $Id: m_locops.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_locops.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -60,12 +60,6 @@ mo_locops(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  if (EmptyString(message))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "LOCOPS");
-    return;
-  }
-
   sendto_realops_flags(UMODE_LOCOPS, L_ALL, SEND_LOCOPS, "from %s: %s",
                        source_p->name, message);
   cluster_distribute(source_p, "LOCOPS", 0, CLUSTER_LOCOPS, message);
@@ -89,9 +83,6 @@ ms_locops(struct Client *source_p, int parc, char *parv[])
   const char *const targets = parv[1];
   const char *const message = parv[2];
 
-  if (parc != 3 || EmptyString(message))
-    return;
-
   sendto_match_servs(source_p, targets, CAPAB_CLUSTER, "LOCOPS %s :%s",
                      targets, message);
 
@@ -106,13 +97,11 @@ ms_locops(struct Client *source_p, int parc, char *parv[])
 static struct Message locops_msgtab =
 {
   .cmd = "LOCOPS",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_locops,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_locops
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_locops, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_locops, .args_min = 2 }
 };
 
 static void
@@ -129,7 +118,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
