@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_lusers.c
  * \brief Includes required functions for processing the LUSERS command.
- * \version $Id: m_lusers.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_lusers.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -62,7 +62,7 @@ m_lusers(struct Client *source_p, int parc, char *parv[])
   last_used = event_base->time.sec_monotonic;
 
   if (ConfigServerHide.disable_remote_commands == 0)
-    if (server_hunt(source_p, ":%s LUSERS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s LUSERS %s :%s", 2, parv)->ret != HUNTED_ISME)
       return;
 
   show_lusers(source_p);
@@ -83,7 +83,7 @@ m_lusers(struct Client *source_p, int parc, char *parv[])
 static void
 ms_lusers(struct Client *source_p, int parc, char *parv[])
 {
-  if (server_hunt(source_p, ":%s LUSERS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s LUSERS %s :%s", 2, parv)->ret != HUNTED_ISME)
     return;
 
   show_lusers(source_p);
@@ -92,12 +92,11 @@ ms_lusers(struct Client *source_p, int parc, char *parv[])
 static struct Message lusers_msgtab =
 {
   .cmd = "LUSERS",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_lusers,
-  .handlers[SERVER_HANDLER] = ms_lusers,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = ms_lusers
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_lusers },
+  .handlers[SERVER_HANDLER] = { .handler = ms_lusers },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = ms_lusers }
 };
 
 static void
@@ -114,7 +113,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
