@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2020 ircd-hybrid development team
+ *  Copyright (c) 2000-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_module.c
  * \brief Includes required functions for processing the MODULE command.
- * \version $Id: m_module.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_module.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -228,12 +228,6 @@ mo_module(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  if (EmptyString(subcmd))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "MODULE");
-    return;
-  }
-
   for (const struct ModuleStruct *tab = module_cmd_table; tab->handler; ++tab)
   {
     if (irccmp(tab->cmd, subcmd))
@@ -257,13 +251,11 @@ mo_module(struct Client *source_p, int parc, char *parv[])
 static struct Message module_msgtab =
 {
   .cmd = "MODULE",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_module
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_module, .args_min = 2 }
 };
 
 static void
@@ -280,7 +272,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_resident = true
