@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_motd.c
  * \brief Includes required functions for processing the MOTD command.
- * \version $Id: m_motd.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_motd.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -77,7 +77,7 @@ m_motd(struct Client *source_p, int parc, char *parv[])
   last_used = event_base->time.sec_monotonic;
 
   if (ConfigServerHide.disable_remote_commands == 0)
-    if (server_hunt(source_p, ":%s MOTD :%s", 1, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s MOTD :%s", 1, parv)->ret != HUNTED_ISME)
       return;
 
   do_motd(source_p);
@@ -97,7 +97,7 @@ m_motd(struct Client *source_p, int parc, char *parv[])
 static void
 ms_motd(struct Client *source_p, int parc, char *parv[])
 {
-  if (server_hunt(source_p, ":%s MOTD :%s", 1, parc, parv)->ret != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s MOTD :%s", 1, parv)->ret != HUNTED_ISME)
     return;
 
   do_motd(source_p);
@@ -106,12 +106,11 @@ ms_motd(struct Client *source_p, int parc, char *parv[])
 static struct Message motd_msgtab =
 {
   .cmd = "MOTD",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_motd,
-  .handlers[SERVER_HANDLER] = ms_motd,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = ms_motd
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_motd },
+  .handlers[SERVER_HANDLER] = { .handler = ms_motd },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = ms_motd }
 };
 
 static void
@@ -128,7 +127,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
