@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_ping.c
  * \brief Includes required functions for processing the PING command.
- * \version $Id: m_ping.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_ping.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -54,7 +54,7 @@ m_ping(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
 
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NOORIGIN);
     return;
@@ -95,7 +95,7 @@ ms_ping(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
 
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NOORIGIN);
     return;
@@ -119,12 +119,11 @@ ms_ping(struct Client *source_p, int parc, char *parv[])
 static struct Message ping_msgtab =
 {
   .cmd = "PING",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_ping,
-  .handlers[SERVER_HANDLER] = ms_ping,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ping
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ping },
+  .handlers[SERVER_HANDLER] = { .handler = ms_ping },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ping }
 };
 
 static void
@@ -141,7 +140,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
