@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_rehash.c
  * \brief Includes required functions for processing the REHASH command.
- * \version $Id: m_rehash.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_rehash.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -123,12 +123,6 @@ mo_rehash(struct Client *source_p, int parc, char *parv[])
   const char *option = NULL;
   const char *server = NULL;
 
-  if (EmptyString(parv[parc - 1]))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "REHASH");
-    return;
-  }
-
   if (parc < 3)
   {
     if (!HasOFlag(source_p, OPER_FLAG_REHASH))
@@ -210,13 +204,11 @@ ms_rehash(struct Client *source_p, int parc, char *parv[])
 static struct Message rehash_msgtab =
 {
   .cmd = "REHASH",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_rehash,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_rehash
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_rehash, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_rehash, .args_min = 2 }
 };
 
 static void
@@ -233,7 +225,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
