@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_restart.c
  * \brief Includes required functions for processing the RESTART command.
- * \version $Id: m_restart.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_restart.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -49,7 +49,6 @@
 static void
 mo_restart(struct Client *source_p, int parc, char *parv[])
 {
-  char buf[IRCD_BUFSIZE];
   const char *const name = parv[1];
 
   if (!HasOFlag(source_p, OPER_FLAG_RESTART))
@@ -58,18 +57,13 @@ mo_restart(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  if (EmptyString(name))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "RESTART");
-    return;
-  }
-
   if (irccmp(name, me.name))
   {
     sendto_one_notice(source_p, &me, ":Mismatch on /restart %s", me.name);
     return;
   }
 
+  char buf[IRCD_BUFSIZE];
   snprintf(buf, sizeof(buf), "received RESTART command from %s",
            client_get_name(source_p, HIDE_IP));
   server_die(buf, true);
@@ -78,12 +72,11 @@ mo_restart(struct Client *source_p, int parc, char *parv[])
 static struct Message restart_msgtab =
 {
   .cmd = "RESTART",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_restart
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_restart, .args_min = 2 }
 };
 
 static void
@@ -100,7 +93,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
