@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2020 ircd-hybrid development team
+ *  Copyright (c) 2011-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svsmode.c
  * \brief Includes required functions for processing the SVSMODE command.
- * \version $Id: m_svsmode.c 9275 2020-02-12 18:46:44Z michael $
+ * \version $Id: m_svsmode.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -51,22 +51,18 @@
  *      - parv[0] = command
  *      - parv[1] = nickname
  *      - parv[2] = TS
- *      - parv[3] = mode
- *      - parv[4] = optional argument (services account, vhost)
+ *      - parv[3] = modes to be added or removed
  */
 static void
 ms_svsmode(struct Client *source_p, int parc, char *parv[])
 {
+  const char *const modes = parv[3];
   const struct user_modes *tab = NULL;
   int what = MODE_ADD;
-  const char *modes = NULL, *extarg = NULL;
 
   if (!HasFlag(source_p, FLAGS_SERVICE))
     return;
 
-  modes  = parv[3];
-  extarg = (parc > 4) ? parv[4] : NULL;
-
   struct Client *target_p = find_person(source_p, parv[1]);
   if (target_p == NULL)
     return;
@@ -88,22 +84,6 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
         what = MODE_DEL;
         break;
 
-      case 'd':
-        if (!EmptyString(extarg))
-        {
-          strlcpy(target_p->account, extarg, sizeof(target_p->account));
-          sendto_common_channels_local(target_p, true, CAP_ACCOUNT_NOTIFY, 0, ":%s!%s@%s ACCOUNT %s",
-                                       target_p->name, target_p->username,
-                                       target_p->host, target_p->account);
-        }
-
-        break;
-
-      case 'x':
-        if (!EmptyString(extarg) && valid_hostname(extarg))
-          user_set_hostmask(target_p, extarg);
-        break;
-
       case 'o':
         if (what == MODE_DEL && HasUMode(target_p, UMODE_OPER))
         {
@@ -157,14 +137,9 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  if (extarg)
-    sendto_server(source_p, 0, 0, ":%s SVSMODE %s %ju %s %s",
-                  source_p->id,
-                  target_p->id, target_p->tsinfo, modes, extarg);
-  else
-    sendto_server(source_p, 0, 0, ":%s SVSMODE %s %ju %s",
-                  source_p->id,
-                  target_p->id, target_p->tsinfo, modes);
+  sendto_server(source_p, 0, 0, ":%s SVSMODE %s %ju %s",
+                source_p->id,
+                target_p->id, target_p->tsinfo, modes);
 
   if (MyConnect(target_p) && (setmodes != target_p->umodes))
   {
@@ -177,13 +152,11 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
 static struct Message svsmode_msgtab =
 {
   .cmd = "SVSMODE",
-  .args_min = 4,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_ignore,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_svsmode,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_svsmode, .args_min = 4 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -200,7 +173,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9275 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
