@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2020 ircd-hybrid development team
+ *  Copyright (c) 2011-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svsnick.c
  * \brief Includes required functions for processing the SVSNICK command.
- * \version $Id: m_svsnick.c 9275 2020-02-12 18:46:44Z michael $
+ * \version $Id: m_svsnick.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 
@@ -37,7 +37,7 @@
 #include "irc_string.h"
 #include "user.h"
 #include "hash.h"
-#include "watch.h"
+#include "monitor.h"
 #include "whowas.h"
 
 
@@ -58,8 +58,7 @@
 static void
 ms_svsnick(struct Client *source_p, int parc, char *parv[])
 {
-  const char *new_nick = parc == 5 ? parv[3] : parv[2];  /* TBR: compatibility mode */
-  uintmax_t ts = 0, new_ts = 0;
+  const char *new_nick = parv[3];
 
   if (!HasFlag(source_p, FLAGS_SERVICE))
     return;
@@ -71,19 +70,11 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
   if (target_p == NULL)
     return;
 
-  if (parc == 5)  /* TBR: compatibility mode */
-  {
-    ts = strtoumax(parv[2], NULL, 10);
-    if (ts && (ts != target_p->tsinfo))
-      return;
-  }
-  else  /* parc == 4 */
-    ts = strtoumax(parv[3], NULL, 10);
+  uintmax_t ts = strtoumax(parv[2], NULL, 10);
+  if (ts && (ts != target_p->tsinfo))
+    return;
 
-  if (parc == 4)  /* TBR: compatibility mode */
-    new_ts = ts;
-  else
-    new_ts = strtoumax(parv[4], NULL, 10);
+  uintmax_t new_ts = strtoumax(parv[4], NULL, 10);
 
   if (!MyConnect(target_p))
   {
@@ -97,8 +88,8 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
       return;
     }
 
-    sendto_one(target_p, ":%s SVSNICK %s %s %s", source_p->id,
-               target_p->id, new_nick, parv[3]);
+    sendto_one(target_p, ":%s SVSNICK %s %ju %s %ju", source_p->id,
+               target_p->id, ts, new_nick, new_ts);
     return;
   }
 
@@ -121,7 +112,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
 
   target_p->tsinfo = new_ts;
   clear_ban_cache_list(&target_p->channel);
-  watch_check_hash(target_p, RPL_LOGOFF);
+  monitor_signoff(target_p);
 
   if (HasUMode(target_p, UMODE_REGISTERED))
   {
@@ -145,7 +136,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
   strlcpy(target_p->name, new_nick, sizeof(target_p->name));
   hash_add_client(target_p);
 
-  watch_check_hash(target_p, RPL_LOGON);
+  monitor_signon(target_p);
 
   fd_note(target_p->connection->fd, "Nick: %s", target_p->name);
 }
@@ -153,13 +144,11 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
 static struct Message svsnick_msgtab =
 {
   .cmd = "SVSNICK",
-  .args_min = 4,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_ignore,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_svsnick,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_svsnick, .args_min = 5 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -176,7 +165,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9275 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
