@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2014-2020 ircd-hybrid development team
+ *  Copyright (c) 2014-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svspart.c
  * \brief Includes required functions for processing the SVSPART command.
- * \version $Id: m_svspart.c 9199 2020-01-23 17:49:06Z michael $
+ * \version $Id: m_svspart.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -55,9 +55,6 @@ ms_svspart(struct Client *source_p, int parc, char *parv[])
   if (!HasFlag(source_p, FLAGS_SERVICE))
     return;
 
-  if (EmptyString(parv[2]))
-    return;
-
   struct Client *target_p = find_person(source_p, parv[1]);
   if (target_p == NULL)
     return;
@@ -78,7 +75,7 @@ ms_svspart(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  if (parc == 3)
+  if (EmptyString(parv[3]))
     sendto_one(target_p, ":%s SVSPART %s %s", source_p->id,
                target_p->id, parv[2]);
   else
@@ -89,13 +86,11 @@ ms_svspart(struct Client *source_p, int parc, char *parv[])
 static struct Message svspart_msgtab =
 {
   .cmd = "SVSPART",
-  .args_min = 3,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_svspart,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_svspart, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -112,7 +107,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9199 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
