@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_time.c
  * \brief Includes required functions for processing the TIME command.
- * \version $Id: m_time.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_time.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -53,7 +53,7 @@ m_time(struct Client *source_p, int parc, char *parv[])
 {
   /* This is safe enough to use during non hidden server mode */
   if (ConfigServerHide.disable_remote_commands == 0)
-    if (server_hunt(source_p, ":%s TIME :%s", 1, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s TIME :%s", 1, parv)->ret != HUNTED_ISME)
       return;
 
   sendto_one_numeric(source_p, &me, RPL_TIME, me.name, date(0));
@@ -73,7 +73,7 @@ m_time(struct Client *source_p, int parc, char *parv[])
 static void
 ms_time(struct Client *source_p, int parc, char *parv[])
 {
-  if (server_hunt(source_p, ":%s TIME :%s", 1, parc, parv)->ret != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s TIME :%s", 1, parv)->ret != HUNTED_ISME)
     return;
 
   sendto_one_numeric(source_p, &me, RPL_TIME, me.name, date(0));
@@ -82,12 +82,11 @@ ms_time(struct Client *source_p, int parc, char *parv[])
 static struct Message time_msgtab =
 {
   .cmd = "TIME",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_time,
-  .handlers[SERVER_HANDLER] = ms_time,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = ms_time
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_time },
+  .handlers[SERVER_HANDLER] = { .handler = ms_time },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = ms_time }
 };
 
 static void
@@ -104,7 +103,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
