@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_topic.c
  * \brief Includes required functions for processing the TOPIC command.
- * \version $Id: m_topic.c 9334 2020-04-18 16:18:49Z michael $
+ * \version $Id: m_topic.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -55,12 +55,6 @@
 static void
 m_topic(struct Client *source_p, int parc, char *parv[])
 {
-  if (EmptyString(parv[1]))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "TOPIC");
-    return;
-  }
-
   struct Channel *channel = hash_find_channel(parv[1]);
   if (channel == NULL)
   {
@@ -71,7 +65,7 @@ m_topic(struct Client *source_p, int parc, char *parv[])
   /* Setting topic */
   if (parc > 2)
   {
-    const struct ChannelMember *member = find_channel_link(source_p, channel);
+    const struct ChannelMember *member = member_find_link(source_p, channel);
     if (member == NULL)
     {
       sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, channel->name);
@@ -79,7 +73,7 @@ m_topic(struct Client *source_p, int parc, char *parv[])
     }
 
     if (!HasCMode(channel, MODE_TOPICLIMIT) ||
-        has_member_flags(member, CHFL_CHANOP | CHFL_HALFOP))
+        member_has_flags(member, CHFL_CHANOP | CHFL_HALFOP) == true)
     {
       char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];  /* +3 for !, @, \0 */
 
@@ -101,7 +95,7 @@ m_topic(struct Client *source_p, int parc, char *parv[])
   }
   else  /* Only asking for topic */
   {
-    if (!SecretChannel(channel) || IsMember(source_p, channel))
+    if (!SecretChannel(channel) || member_find_link(source_p, channel))
     {
       if (channel->topic[0] == '\0')
         sendto_one_numeric(source_p, &me, RPL_NOTOPIC, channel->name);
@@ -135,14 +129,6 @@ m_topic(struct Client *source_p, int parc, char *parv[])
 static void
 ms_topic(struct Client *source_p, int parc, char *parv[])
 {
-  char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];  /* +3 for !, @, \0 */
-
-  if (parc < 3)
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "TOPIC");
-    return;
-  }
-
   struct Channel *channel = hash_find_channel(parv[1]);
   if (channel == NULL)
   {
@@ -150,6 +136,7 @@ ms_topic(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
+  char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];  /* +3 for !, @, \0 */
   if (IsClient(source_p))
     snprintf(topic_info, sizeof(topic_info), "%s!%s@%s", source_p->name,
              source_p->username, source_p->host);
@@ -179,14 +166,11 @@ ms_topic(struct Client *source_p, int parc, char *parv[])
 static struct Message topic_msgtab =
 {
   .cmd = "TOPIC",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .flags = MFLG_ENDGRACE,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_topic,
-  .handlers[SERVER_HANDLER] = ms_topic,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_topic
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_topic, .args_min = 2, .end_grace_period = true },
+  .handlers[SERVER_HANDLER] = { .handler = ms_topic, .args_min = 3, .empty_last_arg = true },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_topic, .args_min = 2, .end_grace_period = true }
 };
 
 static void
@@ -203,7 +187,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9334 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
