@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_undline.c
  * \brief Includes required functions for processing the UNDLINE command.
- * \version $Id: m_undline.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_undline.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -112,12 +112,6 @@ mo_undline(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  if (parc < 2 || EmptyString(parv[parc - 1]))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "UNDLINE");
-    return;
-  }
-
   if (parse_aline("UNDLINE", source_p, parc, parv, &aline) == false)
     return;
 
@@ -159,9 +153,6 @@ ms_undline(struct Client *source_p, int parc, char *parv[])
     .server = parv[1]
   };
 
-  if (parc != 3 || EmptyString(parv[parc - 1]))
-    return;
-
   sendto_match_servs(source_p, aline.server, CAPAB_UNDLN, "UNDLINE %s %s",
                      aline.server, aline.host);
 
@@ -177,13 +168,11 @@ ms_undline(struct Client *source_p, int parc, char *parv[])
 static struct Message undline_msgtab =
 {
   .cmd = "UNDLINE",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_undline,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_undline
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_undline, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_undline, .args_min = 2 }
 };
 
 static void
@@ -202,7 +191,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
