@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2020 ircd-hybrid development team
+ *  Copyright (c) 2001-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unresv.c
  * \brief Includes required functions for processing the UNRESV command.
- * \version $Id: m_unresv.c 9199 2020-01-23 17:49:06Z michael $
+ * \version $Id: m_unresv.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -46,7 +46,6 @@ static void
 resv_remove(struct Client *source_p, const struct aline_ctx *aline)
 {
   struct ResvItem *resv = resv_find(aline->mask, irccmp);
-
   if (resv == NULL)
   {
     if (IsClient(source_p))
@@ -140,9 +139,6 @@ ms_unresv(struct Client *source_p, int parc, char *parv[])
     .server = parv[1]
   };
 
-  if (parc != 3 || EmptyString(parv[parc - 1]))
-    return;
-
   sendto_match_servs(source_p, aline.server, CAPAB_CLUSTER, "UNRESV %s %s",
                      aline.server, aline.mask);
 
@@ -158,13 +154,11 @@ ms_unresv(struct Client *source_p, int parc, char *parv[])
 static struct Message unresv_msgtab =
 {
   .cmd = "UNRESV",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_unresv,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_unresv
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_unresv, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_unresv, .args_min = 2 }
 };
 
 static void
@@ -181,7 +175,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9199 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
