@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2003-2020 ircd-hybrid development team
+ *  Copyright (c) 2003-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unxline.c
  * \brief Includes required functions for processing the UNXLINE command.
- * \version $Id: m_unxline.c 9199 2020-01-23 17:49:06Z michael $
+ * \version $Id: m_unxline.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -52,7 +52,6 @@ static void
 xline_remove(struct Client *source_p, const struct aline_ctx *aline)
 {
   struct GecosItem *gecos = gecos_find(aline->mask, irccmp);
-
   if (gecos == NULL)
   {
     if (IsClient(source_p))
@@ -146,9 +145,6 @@ ms_unxline(struct Client *source_p, int parc, char *parv[])
     .server = parv[1]
   };
 
-  if (parc != 3 || EmptyString(parv[parc - 1]))
-    return;
-
   sendto_match_servs(source_p, aline.server, CAPAB_CLUSTER, "UNXLINE %s %s",
                      aline.server, aline.mask);
 
@@ -164,13 +160,11 @@ ms_unxline(struct Client *source_p, int parc, char *parv[])
 static struct Message unxline_msgtab =
 {
   .cmd = "UNXLINE",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_unxline,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_unxline
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_unxline, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_unxline, .args_min = 2 }
 };
 
 static void
@@ -187,7 +181,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9199 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
