@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2012-2020 ircd-hybrid development team
+ *  Copyright (c) 2012-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_webirc.c
  * \brief Includes required functions for processing the WEBIRC command.
- * \version $Id: m_webirc.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: m_webirc.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -54,11 +54,9 @@
 static void
 mr_webirc(struct Client *source_p, int parc, char *parv[])
 {
-  const struct MaskItem *conf = NULL;
   const char *const pass = parv[1];
   const char *const host = parv[3];
   const char *const addr = parv[4];
-  struct addrinfo hints, *res;
 
   assert(MyConnect(source_p));
 
@@ -68,12 +66,15 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  conf = find_address_conf(source_p->host,
+  const struct MaskItem *conf = find_address_conf(source_p->host,
                            HasFlag(source_p, FLAGS_GOTID) ? source_p->username : "webirc",
                            &source_p->ip, pass);
-  if (!conf || !IsConfClient(conf))
+  if (conf == NULL)
     return;
 
+  if (!IsConfClient(conf))
+    return;  /* It's a CONF_KLINE */
+
   if (!IsConfWebIRC(conf))
   {
     sendto_one_notice(source_p, &me, ":Not a WEBIRC auth {} block");
@@ -92,11 +93,12 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
+  struct addrinfo hints, *res;
   memset(&hints, 0, sizeof(hints));
 
-  hints.ai_family   = AF_UNSPEC;
+  hints.ai_family = AF_UNSPEC;
   hints.ai_socktype = SOCK_STREAM;
-  hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;
+  hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
 
   if (getaddrinfo(addr, NULL, &hints, &res))
   {
@@ -122,7 +124,8 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
   strlcpy(source_p->realhost, host, sizeof(source_p->realhost));
 
   /* Check dlines now, k-lines will be checked on registration */
-  if ((conf = find_dline_conf(&source_p->ip)))
+  conf = find_dline_conf(&source_p->ip);
+  if (conf)
   {
     if (conf->type == CONF_DLINE)
     {
@@ -138,13 +141,11 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
 static struct Message webirc_msgtab =
 {
   .cmd = "WEBIRC",
-  .args_min = 5,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = mr_webirc,
-  .handlers[CLIENT_HANDLER] = m_registered,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_registered
+  .handlers[UNREGISTERED_HANDLER] = { .handler = mr_webirc, .args_min = 5 },
+  .handlers[CLIENT_HANDLER] = { .handler = m_registered },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_registered }
 };
 
 static void
@@ -161,7 +162,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
