@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whois.c
  * \brief Includes required functions for processing the WHOIS command.
- * \version $Id: m_whois.c 9201 2020-01-24 23:51:50Z michael $
+ * \version $Id: m_whois.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -43,20 +43,27 @@
 #include "modules.h"
 
 
+enum
+{
+  WHOIS_SHOW_NORMAL,
+  WHOIS_SHOW_PREFIXED,
+  WHOIS_SHOW_NO
+};
+
 static int
-whois_can_see_channels(struct Channel *channel,
-                       struct Client *source_p,
-                       struct Client *target_p)
+whois_channel_show_type(struct Channel *channel,
+                        struct Client *source_p,
+                        struct Client *target_p)
 {
   if (PubChannel(channel) && !HasUMode(target_p, UMODE_HIDECHANS))
-    return 1;
+    return WHOIS_SHOW_NORMAL;
 
-  if (source_p == target_p || IsMember(source_p, channel))
-    return 1;
+  if (source_p == target_p || member_find_link(source_p, channel))
+    return WHOIS_SHOW_NORMAL;
 
   if (HasUMode(source_p, UMODE_OPER))
-    return 2;
-  return 0;
+    return WHOIS_SHOW_PREFIXED;
+  return WHOIS_SHOW_NO;
 }
 
 /* whois_person()
@@ -69,57 +76,58 @@ whois_can_see_channels(struct Channel *channel,
 static void
 whois_person(struct Client *source_p, struct Client *target_p)
 {
-  char buf[IRCD_BUFSIZE];
   dlink_node *node;
   const struct ServicesTag *svstag = NULL;
-  char *t = NULL;
-  int cur_len = 0;
-  int mlen = 0;
-  int tlen = 0;
-  int reply_to_send = 0;
 
   sendto_one_numeric(source_p, &me, RPL_WHOISUSER, target_p->name,
                      target_p->username, target_p->host,
                      target_p->info);
 
-  cur_len = mlen = snprintf(buf, sizeof(buf), numeric_form(RPL_WHOISCHANNELS),
-                            me.name, source_p->name, target_p->name, "");
-  t = buf + mlen;
-
-  DLINK_FOREACH(node, target_p->channel.head)
+  if (dlink_list_length(&target_p->channel))
   {
-    const struct ChannelMember *member = node->data;
-    int show = whois_can_see_channels(member->channel, source_p, target_p);
+    char buf[IRCD_BUFSIZE];
+    char *bufptr = buf;
 
-    if (show)
+    /* :me.name 319 source_p->name target_p->name :~@#chan1 +#chan2 #chan3 ...\r\n */
+    /* 1       23456              7              89                           0 1  */
+    size_t len = strlen(target_p->name) + 11;
+
+    if (MyConnect(source_p))
+      len += strlen(me.name) + strlen(source_p->name);
+    else
+      len += IRCD_MAX(strlen(me.name), strlen(me.id)) + IRCD_MAX(strlen(source_p->name), strlen(source_p->id));
+
+    DLINK_FOREACH(node, target_p->channel.head)
     {
-      if ((cur_len + 4 + member->channel->name_len + 1) > (IRCD_BUFSIZE - 2))
+      const struct ChannelMember *member = node->data;
+      int show = whois_channel_show_type(member->channel, source_p, target_p);
+
+      if (show != WHOIS_SHOW_NO)
       {
-        *(t - 1) = '\0';
-        sendto_one(source_p, "%s", buf);
-        cur_len = mlen;
-        t = buf + mlen;
+        if ((bufptr - buf) + member->channel->name_len + 1 + (show == WHOIS_SHOW_PREFIXED) + member_get_prefix_len(member, true) + len > sizeof(buf))
+        {
+          *(bufptr - 1) = '\0';
+          sendto_one_numeric(source_p, &me, RPL_WHOISCHANNELS, target_p->name, buf);
+          bufptr = buf;
+        }
+
+        bufptr += snprintf(bufptr, sizeof(buf) - (bufptr - buf), "%s%s%s ",
+                           show == WHOIS_SHOW_PREFIXED ? "~" : "", member_get_prefix(member, true), member->channel->name);
       }
-
-      tlen = sprintf(t, "%s%s%s ", show == 2 ? "~" : "", get_member_status(member, true),
-                     member->channel->name);
-      t += tlen;
-      cur_len += tlen;
-      reply_to_send = 1;
     }
-  }
 
-  if (reply_to_send)
-  {
-    *(t - 1) = '\0';
-    sendto_one(source_p, "%s", buf);
+    if (bufptr != buf)
+    {
+      *(bufptr - 1) = '\0';
+      sendto_one_numeric(source_p, &me, RPL_WHOISCHANNELS, target_p->name, buf);
+    }
   }
 
   if ((ConfigServerHide.hide_servers || IsHidden(target_p->servptr)) &&
       !(HasUMode(source_p, UMODE_OPER) || source_p == target_p))
     sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, target_p->name,
                        ConfigServerHide.hidden_name,
-                       ConfigServerInfo.network_desc);
+                       ConfigServerInfo.network_description);
   else
     sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, target_p->name,
                        target_p->servptr->name, target_p->servptr->info);
@@ -179,15 +187,19 @@ whois_person(struct Client *source_p, struct Client *target_p)
                          target_p->name, svstag->tag);
   }
 
+  if (HasUMode(target_p, UMODE_BOT))
+    sendto_one_numeric(source_p, &me, RPL_WHOISBOT, target_p->name);
+
   if (HasUMode(target_p, UMODE_WEBIRC))
     sendto_one_numeric(source_p, &me, RPL_WHOISTEXT, target_p->name,
                        "User connected using a webirc gateway");
 
   if (HasUMode(source_p, UMODE_OPER) || source_p == target_p)
   {
+    char buf[UMODE_MAX_STR];
     char *m = buf;
-    *m++ = '+';
 
+    *m++ = '+';
     for (const struct user_modes *tab = umode_tab; tab->c; ++tab)
       if (HasUMode(target_p, tab->flag))
         *m++ = tab->c;
@@ -204,9 +216,9 @@ whois_person(struct Client *source_p, struct Client *target_p)
   if (HasUMode(target_p, UMODE_SECURE))
     sendto_one_numeric(source_p, &me, RPL_WHOISSECURE, target_p->name);
 
-  if (!EmptyString(target_p->certfp))
+  if (!EmptyString(target_p->tls_certfp))
     if (HasUMode(source_p, UMODE_OPER) || source_p == target_p)
-      sendto_one_numeric(source_p, &me, RPL_WHOISCERTFP, target_p->name, target_p->certfp);
+      sendto_one_numeric(source_p, &me, RPL_WHOISCERTFP, target_p->name, target_p->tls_certfp);
 
   if (MyConnect(target_p))
     if (!HasUMode(target_p, UMODE_HIDEIDLE) || HasUMode(source_p, UMODE_OPER) ||
@@ -258,13 +270,13 @@ m_whois(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
 
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
     return;
   }
 
-  if (parc > 2 && !EmptyString(parv[2]))
+  if (!EmptyString(parv[2]))
   {
     /* seeing as this is going across servers, we should limit it */
     if ((last_used + ConfigGeneral.pace_wait_simple) > event_base->time.sec_monotonic)
@@ -283,7 +295,7 @@ m_whois(struct Client *source_p, int parc, char *parv[])
     if (ConfigServerHide.disable_remote_commands)
       parv[1] = parv[2];
 
-    if (server_hunt(source_p, ":%s WHOIS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s WHOIS %s :%s", 1, parv)->ret != HUNTED_ISME)
       return;
 
     parv[1] = parv[2];
@@ -307,15 +319,15 @@ m_whois(struct Client *source_p, int parc, char *parv[])
 static void
 mo_whois(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
     return;
   }
 
-  if (parc > 2 && !EmptyString(parv[2]))
+  if (!EmptyString(parv[2]))
   {
-    if (server_hunt(source_p, ":%s WHOIS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s WHOIS %s :%s", 1, parv)->ret != HUNTED_ISME)
       return;
 
     parv[1] = parv[2];
@@ -327,12 +339,11 @@ mo_whois(struct Client *source_p, int parc, char *parv[])
 static struct Message whois_msgtab =
 {
   .cmd = "WHOIS",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_whois,
-  .handlers[SERVER_HANDLER] = mo_whois,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_whois
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_whois },
+  .handlers[SERVER_HANDLER] = { .handler = mo_whois },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_whois }
 };
 
 static void
@@ -349,7 +360,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9201 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
