@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2003-2020 ircd-hybrid development team
+ *  Copyright (c) 2003-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_xline.c
  * \brief Includes required functions for processing the XLINE command.
- * \version $Id: m_xline.c 9199 2020-01-23 17:49:06Z michael $
+ * \version $Id: m_xline.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -50,13 +50,13 @@ xline_check(const struct GecosItem *gecos)
 
   DLINK_FOREACH_SAFE(node, node_next, local_client_list.head)
   {
-    struct Client *client_p = node->data;
+    struct Client *client = node->data;
 
-    if (IsDead(client_p))
+    if (IsDead(client))
       continue;
 
-    if (match(gecos->mask, client_p->info) == 0)
-      conf_try_ban(client_p, CLIENT_BAN_XLINE, gecos->reason);
+    if (match(gecos->mask, client->info) == 0)
+      conf_try_ban(client, CLIENT_BAN_XLINE, gecos->reason);
   }
 }
 
@@ -202,9 +202,6 @@ ms_xline(struct Client *source_p, int parc, char *parv[])
     .duration = strtoumax(parv[3], NULL, 10)
   };
 
-  if (parc != 5 || EmptyString(parv[parc - 1]))
-    return;
-
   sendto_match_servs(source_p, aline.server, CAPAB_CLUSTER, "XLINE %s %s %ju :%s",
                      aline.server, aline.mask, aline.duration, aline.reason);
 
@@ -220,13 +217,11 @@ ms_xline(struct Client *source_p, int parc, char *parv[])
 static struct Message xline_msgtab =
 {
   .cmd = "XLINE",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_xline,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_xline
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_xline, .args_min = 5 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_xline, .args_min = 2 }
 };
 
 static void
@@ -243,7 +238,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9199 $",
+  .version = "$Revision: 9858 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
