@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file auth.c
  * \brief Implementation of DNS and ident lookups.
- * \version $Id: auth.c 9249 2020-02-01 13:35:32Z michael $
+ * \version $Id: auth.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 /*
@@ -52,6 +52,7 @@
 #include "send.h"
 #include "memory.h"
 #include "misc.h"
+#include "hostmask.h"
 
 
 enum
@@ -141,8 +142,6 @@ auth_release_client(struct AuthRequest *auth)
 
   AddFlag(client, FLAGS_FINISHED_AUTH);
 
-  strlcpy(client->realhost, client->host, sizeof(client->realhost));
-
   read_packet(client->connection->fd, client);
 }
 
@@ -186,7 +185,7 @@ auth_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, s
 
   if (namelength == 0)
     auth_sendheader(auth->client, REPORT_FAIL_DNS);
-  else if (address_compare(addr, &auth->client->ip, false) == false)
+  else if (address_compare(addr, &auth->client->ip, true, false, 0) == false)
     auth_sendheader(auth->client, REPORT_IP_MISMATCH);
   else if (namelength > HOSTLEN)
     auth_sendheader(auth->client, REPORT_HOST_TOOLONG);
