@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf.c
  * \brief Configuration file functions.
- * \version $Id$
+ * \version $Id: conf.c 9897 2021-01-17 06:18:18Z michael $
  */
 
 #include "stdinc.h"
@@ -260,6 +260,8 @@ attach_iline(struct Client *client, struct MaskItem *conf)
   else if (class->max_perip_global &&
            (ipcache->count_local + ipcache->count_remote) > class->max_perip_global)
     a_limit_reached = true;
+  else if (class_ip_limit_add(conf->class, &client->ip, IsConfExemptLimits(conf)) == true)
+    a_limit_reached = true;
 
   if (a_limit_reached == true)
   {
@@ -340,58 +342,43 @@ verify_access(struct Client *client)
 bool
 conf_check_client(struct Client *client)
 {
-  int i;
+  const char *error = NULL;
+  bool warn = true;
 
-  if ((i = verify_access(client)))
-    ilog(LOG_TYPE_IRCD, "Access denied: %s[%s]",
-         client->name, client->sockhost);
-
-  switch (i)
+  switch (verify_access(client))
   {
     case TOO_MANY:
-      sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
-                           "Too many on IP for %s (%s).",
-                           client_get_name(client, SHOW_IP),
-                           client->sockhost);
-      ilog(LOG_TYPE_IRCD, "Too many connections on IP from %s.",
-           client_get_name(client, SHOW_IP));
-      ++ServerStats.is_ref;
-      exit_client(client, "No more connections allowed on that IP");
+      error = "too many connections on IP";
       break;
-
     case I_LINE_FULL:
-      sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
-                           "auth {} block is full for %s (%s).",
-                           client_get_name(client, SHOW_IP),
-                           client->sockhost);
-      ilog(LOG_TYPE_IRCD, "Too many connections from %s.",
-           client_get_name(client, SHOW_IP));
-      ++ServerStats.is_ref;
-      exit_client(client, "No more connections allowed in your connection class");
+      error = "connection class is full";
       break;
-
     case NOT_AUTHORIZED:
-      sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
-                           "Unauthorized client connection from %s.",
-                           client_get_name(client, SHOW_IP));
-      ilog(LOG_TYPE_IRCD, "Unauthorized client connection from %s.",
-           client_get_name(client, SHOW_IP));
-      ++ServerStats.is_ref;
-      exit_client(client, "You are not authorized to use this server");
+      error = "not authorized";
       break;
-
     case BANNED_CLIENT:
-      ++ServerStats.is_ref;
-      exit_client(client, "Banned");
-      break;
-
-    case 0:
-    default:
+      error = "banned from server";
+      warn = false;
       break;
   }
 
-  if (i < 0)
+  if (error)
+  {
+    char buf[REASONLEN + 1];
+    snprintf(buf, sizeof(buf), "Connection rejected - %s", error);
+
+    ++ServerStats.is_ref;
+
+    if (warn == true)
+      sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE, "Rejecting client connection from %s: %s",
+                           client_get_name(client, SHOW_IP), error);
+
+    ilog(LOG_TYPE_IRCD, "Rejecting client connection from %s: %s",
+         client_get_name(client, SHOW_IP), error);
+    exit_client(client, buf);
     return false;
+  }
+
   return true;
 }
 
@@ -445,10 +432,6 @@ conf_attach(struct Client *client, struct MaskItem *conf)
   if (dlinkFind(&client->connection->confs, conf))
     return 1;
 
-  if (conf->type == CONF_CLIENT)
-    if (class_ip_limit_add(conf->class, &client->ip, IsConfExemptLimits(conf)) == true)
-      return TOO_MANY;    /* Already at maximum allowed */
-
   conf->class->ref_count++;
   conf->ref_count++;
 
@@ -625,7 +608,7 @@ conf_set_defaults(void)
   ConfigGeneral.default_floodcount = 8;
   ConfigGeneral.default_floodtime = 1;
   ConfigGeneral.failed_oper_notice = 1;
-  ConfigGeneral.dots_in_ident = 0;
+  ConfigGeneral.specials_in_ident = 0;
   ConfigGeneral.min_nonwildcard = 4;
   ConfigGeneral.min_nonwildcard_simple = 3;
   ConfigGeneral.max_accept = 50;
