@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_class.c
  * \brief Configuration managment for class{} blocks
- * \version $Id$
+ * \version $Id: conf_class.c 9884 2021-01-15 13:47:56Z michael $
  */
 
 #include "stdinc.h"
@@ -208,8 +208,19 @@ class_ip_limit_add(struct ClassItem *class, void *addr, bool over_rule)
     return false;
 
   patricia_node_t *pnode = patricia_make_and_lookup_addr(class_ip_limit_trie(class, addr), addr, bitlen);
-  if (((uintptr_t)pnode->data) >= class->number_per_cidr && over_rule == false)
+  if (((uintptr_t)pnode->data) >= class->number_per_cidr)
+  {
+    if (over_rule == true)
+      /*
+       * In case of overruling, we continue with the client registration process
+       * which means we expect a class_ip_limit_remove() call when detaching the
+       * configuration record upon client exit, therefore pnode->data has to be
+       * increased.
+       */
+      PATRICIA_DATA_SET(pnode, (((uintptr_t)pnode->data) + 1));
+
     return true;
+  }
 
   PATRICIA_DATA_SET(pnode, (((uintptr_t)pnode->data) + 1));
   return false;
