@@ -86,115 +86,115 @@ extern int yydebug;
     DISABLE_REMOTE_COMMANDS = 292,
     DLINE_MIN_CIDR = 293,
     DLINE_MIN_CIDR6 = 294,
-    DOTS_IN_IDENT = 295,
-    EMAIL = 296,
-    ENABLE_EXTBANS = 297,
-    ENCRYPTED = 298,
-    EXCEED_LIMIT = 299,
-    EXEMPT = 300,
-    EXPIRATION = 301,
-    FAILED_OPER_NOTICE = 302,
-    FLATTEN_LINKS = 303,
-    FLATTEN_LINKS_DELAY = 304,
-    FLATTEN_LINKS_FILE = 305,
-    GECOS = 306,
-    GENERAL = 307,
-    HIDDEN = 308,
-    HIDDEN_NAME = 309,
-    HIDE_CHANS = 310,
-    HIDE_IDLE = 311,
-    HIDE_IDLE_FROM_OPERS = 312,
-    HIDE_SERVER_IPS = 313,
-    HIDE_SERVERS = 314,
-    HIDE_SERVICES = 315,
-    HOST = 316,
-    HUB = 317,
-    HUB_MASK = 318,
-    INVISIBLE_ON_CONNECT = 319,
-    INVITE_CLIENT_COUNT = 320,
-    INVITE_CLIENT_TIME = 321,
-    INVITE_DELAY_CHANNEL = 322,
-    INVITE_EXPIRE_TIME = 323,
-    IP = 324,
-    IRCD_AUTH = 325,
-    IRCD_FLAGS = 326,
-    IRCD_SID = 327,
-    JOIN = 328,
-    KILL = 329,
-    KILL_CHASE_TIME_LIMIT = 330,
-    KLINE = 331,
-    KLINE_EXEMPT = 332,
-    KLINE_MIN_CIDR = 333,
-    KLINE_MIN_CIDR6 = 334,
-    KNOCK_CLIENT_COUNT = 335,
-    KNOCK_CLIENT_TIME = 336,
-    KNOCK_DELAY_CHANNEL = 337,
-    LEAF_MASK = 338,
-    LISTEN = 339,
-    MASK = 340,
-    MAX_ACCEPT = 341,
-    MAX_BANS = 342,
-    MAX_BANS_LARGE = 343,
-    MAX_CHANNELS = 344,
-    MAX_IDLE = 345,
-    MAX_INVITES = 346,
-    MAX_MONITOR = 347,
-    MAX_NICK_CHANGES = 348,
-    MAX_NICK_LENGTH = 349,
-    MAX_NICK_TIME = 350,
-    MAX_NUMBER = 351,
-    MAX_TARGETS = 352,
-    MAX_TOPIC_LENGTH = 353,
-    MIN_IDLE = 354,
-    MIN_NONWILDCARD = 355,
-    MIN_NONWILDCARD_SIMPLE = 356,
-    MODULE = 357,
-    MODULES = 358,
-    MOTD = 359,
-    NAME = 360,
-    NEED_IDENT = 361,
-    NEED_PASSWORD = 362,
-    NETWORK_DESCRIPTION = 363,
-    NETWORK_NAME = 364,
-    NICK = 365,
-    NO_OPER_FLOOD = 366,
-    NO_TILDE = 367,
-    NUMBER_PER_CIDR = 368,
-    NUMBER_PER_IP_GLOBAL = 369,
-    NUMBER_PER_IP_LOCAL = 370,
-    OPER_ONLY_UMODES = 371,
-    OPER_UMODES = 372,
-    OPERATOR = 373,
-    OPERS_BYPASS_CALLERID = 374,
-    PACE_WAIT = 375,
-    PACE_WAIT_SIMPLE = 376,
-    PASSWORD = 377,
-    PATH = 378,
-    PING_COOKIE = 379,
-    PING_TIME = 380,
-    PORT = 381,
-    RANDOM_IDLE = 382,
-    REASON = 383,
-    REDIRPORT = 384,
-    REDIRSERV = 385,
-    REHASH = 386,
-    REMOTE = 387,
-    REMOTEBAN = 388,
-    RESV = 389,
-    RESV_EXEMPT = 390,
-    RSA_PRIVATE_KEY_FILE = 391,
-    SECONDS = 392,
-    MINUTES = 393,
-    HOURS = 394,
-    DAYS = 395,
-    WEEKS = 396,
-    MONTHS = 397,
-    YEARS = 398,
-    SEND_PASSWORD = 399,
-    SENDQ = 400,
-    SERVERHIDE = 401,
-    SERVERINFO = 402,
-    SHORT_MOTD = 403,
+    EMAIL = 295,
+    ENABLE_EXTBANS = 296,
+    ENCRYPTED = 297,
+    EXCEED_LIMIT = 298,
+    EXEMPT = 299,
+    EXPIRATION = 300,
+    FAILED_OPER_NOTICE = 301,
+    FLATTEN_LINKS = 302,
+    FLATTEN_LINKS_DELAY = 303,
+    FLATTEN_LINKS_FILE = 304,
+    GECOS = 305,
+    GENERAL = 306,
+    HIDDEN = 307,
+    HIDDEN_NAME = 308,
+    HIDE_CHANS = 309,
+    HIDE_IDLE = 310,
+    HIDE_IDLE_FROM_OPERS = 311,
+    HIDE_SERVER_IPS = 312,
+    HIDE_SERVERS = 313,
+    HIDE_SERVICES = 314,
+    HOST = 315,
+    HUB = 316,
+    HUB_MASK = 317,
+    INVISIBLE_ON_CONNECT = 318,
+    INVITE_CLIENT_COUNT = 319,
+    INVITE_CLIENT_TIME = 320,
+    INVITE_DELAY_CHANNEL = 321,
+    INVITE_EXPIRE_TIME = 322,
+    IP = 323,
+    IRCD_AUTH = 324,
+    IRCD_FLAGS = 325,
+    IRCD_SID = 326,
+    JOIN = 327,
+    KILL = 328,
+    KILL_CHASE_TIME_LIMIT = 329,
+    KLINE = 330,
+    KLINE_EXEMPT = 331,
+    KLINE_MIN_CIDR = 332,
+    KLINE_MIN_CIDR6 = 333,
+    KNOCK_CLIENT_COUNT = 334,
+    KNOCK_CLIENT_TIME = 335,
+    KNOCK_DELAY_CHANNEL = 336,
+    LEAF_MASK = 337,
+    LISTEN = 338,
+    MASK = 339,
+    MAX_ACCEPT = 340,
+    MAX_BANS = 341,
+    MAX_BANS_LARGE = 342,
+    MAX_CHANNELS = 343,
+    MAX_IDLE = 344,
+    MAX_INVITES = 345,
+    MAX_MONITOR = 346,
+    MAX_NICK_CHANGES = 347,
+    MAX_NICK_LENGTH = 348,
+    MAX_NICK_TIME = 349,
+    MAX_NUMBER = 350,
+    MAX_TARGETS = 351,
+    MAX_TOPIC_LENGTH = 352,
+    MIN_IDLE = 353,
+    MIN_NONWILDCARD = 354,
+    MIN_NONWILDCARD_SIMPLE = 355,
+    MODULE = 356,
+    MODULES = 357,
+    MOTD = 358,
+    NAME = 359,
+    NEED_IDENT = 360,
+    NEED_PASSWORD = 361,
+    NETWORK_DESCRIPTION = 362,
+    NETWORK_NAME = 363,
+    NICK = 364,
+    NO_OPER_FLOOD = 365,
+    NO_TILDE = 366,
+    NUMBER_PER_CIDR = 367,
+    NUMBER_PER_IP_GLOBAL = 368,
+    NUMBER_PER_IP_LOCAL = 369,
+    OPER_ONLY_UMODES = 370,
+    OPER_UMODES = 371,
+    OPERATOR = 372,
+    OPERS_BYPASS_CALLERID = 373,
+    PACE_WAIT = 374,
+    PACE_WAIT_SIMPLE = 375,
+    PASSWORD = 376,
+    PATH = 377,
+    PING_COOKIE = 378,
+    PING_TIME = 379,
+    PORT = 380,
+    RANDOM_IDLE = 381,
+    REASON = 382,
+    REDIRPORT = 383,
+    REDIRSERV = 384,
+    REHASH = 385,
+    REMOTE = 386,
+    REMOTEBAN = 387,
+    RESV = 388,
+    RESV_EXEMPT = 389,
+    RSA_PRIVATE_KEY_FILE = 390,
+    SECONDS = 391,
+    MINUTES = 392,
+    HOURS = 393,
+    DAYS = 394,
+    WEEKS = 395,
+    MONTHS = 396,
+    YEARS = 397,
+    SEND_PASSWORD = 398,
+    SENDQ = 399,
+    SERVERHIDE = 400,
+    SERVERINFO = 401,
+    SHORT_MOTD = 402,
+    SPECIALS_IN_IDENT = 403,
     SPOOF = 404,
     SQUIT = 405,
     STATS_E_DISABLED = 406,
@@ -318,115 +318,115 @@ extern int yydebug;
 #define DISABLE_REMOTE_COMMANDS 292
 #define DLINE_MIN_CIDR 293
 #define DLINE_MIN_CIDR6 294
-#define DOTS_IN_IDENT 295
-#define EMAIL 296
-#define ENABLE_EXTBANS 297
-#define ENCRYPTED 298
-#define EXCEED_LIMIT 299
-#define EXEMPT 300
-#define EXPIRATION 301
-#define FAILED_OPER_NOTICE 302
-#define FLATTEN_LINKS 303
-#define FLATTEN_LINKS_DELAY 304
-#define FLATTEN_LINKS_FILE 305
-#define GECOS 306
-#define GENERAL 307
-#define HIDDEN 308
-#define HIDDEN_NAME 309
-#define HIDE_CHANS 310
-#define HIDE_IDLE 311
-#define HIDE_IDLE_FROM_OPERS 312
-#define HIDE_SERVER_IPS 313
-#define HIDE_SERVERS 314
-#define HIDE_SERVICES 315
-#define HOST 316
-#define HUB 317
-#define HUB_MASK 318
-#define INVISIBLE_ON_CONNECT 319
-#define INVITE_CLIENT_COUNT 320
-#define INVITE_CLIENT_TIME 321
-#define INVITE_DELAY_CHANNEL 322
-#define INVITE_EXPIRE_TIME 323
-#define IP 324
-#define IRCD_AUTH 325
-#define IRCD_FLAGS 326
-#define IRCD_SID 327
-#define JOIN 328
-#define KILL 329
-#define KILL_CHASE_TIME_LIMIT 330
-#define KLINE 331
-#define KLINE_EXEMPT 332
-#define KLINE_MIN_CIDR 333
-#define KLINE_MIN_CIDR6 334
-#define KNOCK_CLIENT_COUNT 335
-#define KNOCK_CLIENT_TIME 336
-#define KNOCK_DELAY_CHANNEL 337
-#define LEAF_MASK 338
-#define LISTEN 339
-#define MASK 340
-#define MAX_ACCEPT 341
-#define MAX_BANS 342
-#define MAX_BANS_LARGE 343
-#define MAX_CHANNELS 344
-#define MAX_IDLE 345
-#define MAX_INVITES 346
-#define MAX_MONITOR 347
-#define MAX_NICK_CHANGES 348
-#define MAX_NICK_LENGTH 349
-#define MAX_NICK_TIME 350
-#define MAX_NUMBER 351
-#define MAX_TARGETS 352
-#define MAX_TOPIC_LENGTH 353
-#define MIN_IDLE 354
-#define MIN_NONWILDCARD 355
-#define MIN_NONWILDCARD_SIMPLE 356
-#define MODULE 357
-#define MODULES 358
-#define MOTD 359
-#define NAME 360
-#define NEED_IDENT 361
-#define NEED_PASSWORD 362
-#define NETWORK_DESCRIPTION 363
-#define NETWORK_NAME 364
-#define NICK 365
-#define NO_OPER_FLOOD 366
-#define NO_TILDE 367
-#define NUMBER_PER_CIDR 368
-#define NUMBER_PER_IP_GLOBAL 369
-#define NUMBER_PER_IP_LOCAL 370
-#define OPER_ONLY_UMODES 371
-#define OPER_UMODES 372
-#define OPERATOR 373
-#define OPERS_BYPASS_CALLERID 374
-#define PACE_WAIT 375
-#define PACE_WAIT_SIMPLE 376
-#define PASSWORD 377
-#define PATH 378
-#define PING_COOKIE 379
-#define PING_TIME 380
-#define PORT 381
-#define RANDOM_IDLE 382
-#define REASON 383
-#define REDIRPORT 384
-#define REDIRSERV 385
-#define REHASH 386
-#define REMOTE 387
-#define REMOTEBAN 388
-#define RESV 389
-#define RESV_EXEMPT 390
-#define RSA_PRIVATE_KEY_FILE 391
-#define SECONDS 392
-#define MINUTES 393
-#define HOURS 394
-#define DAYS 395
-#define WEEKS 396
-#define MONTHS 397
-#define YEARS 398
-#define SEND_PASSWORD 399
-#define SENDQ 400
-#define SERVERHIDE 401
-#define SERVERINFO 402
-#define SHORT_MOTD 403
+#define EMAIL 295
+#define ENABLE_EXTBANS 296
+#define ENCRYPTED 297
+#define EXCEED_LIMIT 298
+#define EXEMPT 299
+#define EXPIRATION 300
+#define FAILED_OPER_NOTICE 301
+#define FLATTEN_LINKS 302
+#define FLATTEN_LINKS_DELAY 303
+#define FLATTEN_LINKS_FILE 304
+#define GECOS 305
+#define GENERAL 306
+#define HIDDEN 307
+#define HIDDEN_NAME 308
+#define HIDE_CHANS 309
+#define HIDE_IDLE 310
+#define HIDE_IDLE_FROM_OPERS 311
+#define HIDE_SERVER_IPS 312
+#define HIDE_SERVERS 313
+#define HIDE_SERVICES 314
+#define HOST 315
+#define HUB 316
+#define HUB_MASK 317
+#define INVISIBLE_ON_CONNECT 318
+#define INVITE_CLIENT_COUNT 319
+#define INVITE_CLIENT_TIME 320
+#define INVITE_DELAY_CHANNEL 321
+#define INVITE_EXPIRE_TIME 322
+#define IP 323
+#define IRCD_AUTH 324
+#define IRCD_FLAGS 325
+#define IRCD_SID 326
+#define JOIN 327
+#define KILL 328
+#define KILL_CHASE_TIME_LIMIT 329
+#define KLINE 330
+#define KLINE_EXEMPT 331
+#define KLINE_MIN_CIDR 332
+#define KLINE_MIN_CIDR6 333
+#define KNOCK_CLIENT_COUNT 334
+#define KNOCK_CLIENT_TIME 335
+#define KNOCK_DELAY_CHANNEL 336
+#define LEAF_MASK 337
+#define LISTEN 338
+#define MASK 339
+#define MAX_ACCEPT 340
+#define MAX_BANS 341
+#define MAX_BANS_LARGE 342
+#define MAX_CHANNELS 343
+#define MAX_IDLE 344
+#define MAX_INVITES 345
+#define MAX_MONITOR 346
+#define MAX_NICK_CHANGES 347
+#define MAX_NICK_LENGTH 348
+#define MAX_NICK_TIME 349
+#define MAX_NUMBER 350
+#define MAX_TARGETS 351
+#define MAX_TOPIC_LENGTH 352
+#define MIN_IDLE 353
+#define MIN_NONWILDCARD 354
+#define MIN_NONWILDCARD_SIMPLE 355
+#define MODULE 356
+#define MODULES 357
+#define MOTD 358
+#define NAME 359
+#define NEED_IDENT 360
+#define NEED_PASSWORD 361
+#define NETWORK_DESCRIPTION 362
+#define NETWORK_NAME 363
+#define NICK 364
+#define NO_OPER_FLOOD 365
+#define NO_TILDE 366
+#define NUMBER_PER_CIDR 367
+#define NUMBER_PER_IP_GLOBAL 368
+#define NUMBER_PER_IP_LOCAL 369
+#define OPER_ONLY_UMODES 370
+#define OPER_UMODES 371
+#define OPERATOR 372
+#define OPERS_BYPASS_CALLERID 373
+#define PACE_WAIT 374
+#define PACE_WAIT_SIMPLE 375
+#define PASSWORD 376
+#define PATH 377
+#define PING_COOKIE 378
+#define PING_TIME 379
+#define PORT 380
+#define RANDOM_IDLE 381
+#define REASON 382
+#define REDIRPORT 383
+#define REDIRSERV 384
+#define REHASH 385
+#define REMOTE 386
+#define REMOTEBAN 387
+#define RESV 388
+#define RESV_EXEMPT 389
+#define RSA_PRIVATE_KEY_FILE 390
+#define SECONDS 391
+#define MINUTES 392
+#define HOURS 393
+#define DAYS 394
+#define WEEKS 395
+#define MONTHS 396
+#define YEARS 397
+#define SEND_PASSWORD 398
+#define SENDQ 399
+#define SERVERHIDE 400
+#define SERVERINFO 401
+#define SHORT_MOTD 402
+#define SPECIALS_IN_IDENT 403
 #define SPOOF 404
 #define SQUIT 405
 #define STATS_E_DISABLED 406
