@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2014-2020 ircd-hybrid development team
+ *  Copyright (c) 2014-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_pseudo.c
  * \brief Handles with pseudo commands/service aliases.
- * \version $Id: conf_pseudo.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: conf_pseudo.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -51,7 +51,7 @@ pseudo_get_list(void)
 static void
 pseudo_message_handler(struct Client *source_p, int parc, char *parv[])
 {
-  char buffer[IRCD_BUFSIZE] = "";
+  char buf[IRCD_BUFSIZE];
   const struct PseudoItem *const pseudo = (const struct PseudoItem *)parv[1];
   struct Client *target_p = NULL;
   struct Client *server_p = NULL;
@@ -65,8 +65,8 @@ pseudo_message_handler(struct Client *source_p, int parc, char *parv[])
 
   if (pseudo->prepend)
   {
-    snprintf(buffer, sizeof(buffer), "%s%s", pseudo->prepend, msg);
-    msg = buffer;
+    snprintf(buf, sizeof(buf), "%s%s", pseudo->prepend, msg);
+    msg = buf;
   }
 
   target_p = find_person(source_p, pseudo->nick);
@@ -95,14 +95,12 @@ pseudo_register(const char *name, const char *nick, const char *serv,
     pseudo->prepend = xstrdup(prepend);
 
   pseudo->msg.cmd = pseudo->command;
-  pseudo->msg.args_max = 2;
-  pseudo->msg.flags = MFLG_EXTRA;
   pseudo->msg.extra = pseudo;
-  pseudo->msg.handlers[UNREGISTERED_HANDLER] = m_unregistered;
-  pseudo->msg.handlers[CLIENT_HANDLER] = pseudo_message_handler;
-  pseudo->msg.handlers[SERVER_HANDLER] = m_ignore;
-  pseudo->msg.handlers[ENCAP_HANDLER] = m_ignore;
-  pseudo->msg.handlers[OPER_HANDLER] = pseudo_message_handler;
+  pseudo->msg.handlers[UNREGISTERED_HANDLER] = (struct MessageHandler) { .handler = m_unregistered };
+  pseudo->msg.handlers[CLIENT_HANDLER] = (struct MessageHandler) { .handler = pseudo_message_handler, .args_max = 2 };
+  pseudo->msg.handlers[SERVER_HANDLER] = (struct MessageHandler) { .handler = m_ignore };
+  pseudo->msg.handlers[ENCAP_HANDLER] = (struct MessageHandler) { .handler = m_ignore };
+  pseudo->msg.handlers[OPER_HANDLER] = (struct MessageHandler) { .handler = pseudo_message_handler, .args_max = 2 };
   dlinkAdd(pseudo, &pseudo->node, &pseudo_list);
 
   mod_add_cmd(&pseudo->msg);
