@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd.c
  * \brief Starts up and runs the ircd.
- * \version $Id: ircd.c 9323 2020-03-29 10:40:17Z michael $
+ * \version $Id: ircd.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -56,7 +56,6 @@
 #include "ipcache.h"
 #include "isupport.h"
 #include "patchlevel.h"
-#include "serno.h"
 #include "extban.h"
 
 
@@ -111,7 +110,7 @@ static struct event event_try_connections =
 {
   .name = "try_connections",
   .handler = try_connections,
-  .when = 5
+  .when = 15
 };
 
 static struct event event_comm_checktimeouts =
@@ -313,7 +312,7 @@ setup_fdlimit(void)
 static void
 print_startup(int pid)
 {
-  printf("ircd: version %s(%s)\n", PATCHLEVEL, SERIALNUM);
+  printf("ircd: version %s\n", PATCHLEVEL);
   printf("ircd: pid %d\n", pid);
   printf("ircd: running in %s mode from %s\n", !server_state.foreground ? "background"
          : "foreground", ConfigGeneral.dpath);
@@ -377,7 +376,7 @@ main(int argc, char *argv[])
 
   if (printVersion == true)
   {
-    printf("ircd: version %s(%s)\n", PATCHLEVEL, SERIALNUM);
+    printf("ircd: version %s\n", PATCHLEVEL);
     exit(EXIT_SUCCESS);
   }
 
@@ -490,7 +489,7 @@ main(int argc, char *argv[])
     event_add(&event_write_links_file, NULL);
   }
 
-  ilog(LOG_TYPE_IRCD, "Server ready. Running version: %s(%s)", PATCHLEVEL, SERIALNUM);
+  ilog(LOG_TYPE_IRCD, "Server ready. Running version: %s", PATCHLEVEL);
   io_loop();
 
   return 0;
