@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file misc.c
  * \brief Yet another miscellaneous functions file.
- * \version $Id: misc.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id: misc.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -140,38 +140,3 @@ binary_to_hex(const unsigned char *bin, char *hex, unsigned int length)
 
   *hex = '\0';
 }
-
-bool
-address_compare(const void *p1,
-                const void *p2, bool port)
-{
-  const struct irc_ssaddr *const addr1 = p1;
-  const struct irc_ssaddr *const addr2 = p2;
-
-  if (addr1->ss.ss_family != addr2->ss.ss_family)
-    return false;
-
-  if (addr1->ss.ss_family == AF_INET)
-  {
-    const struct sockaddr_in *const sin1 = (const struct sockaddr_in *)addr1;
-    const struct sockaddr_in *const sin2 = (const struct sockaddr_in *)addr2;
-
-    if (port == true && (sin1->sin_port != sin2->sin_port))
-      return false;
-
-    return sin1->sin_addr.s_addr == sin2->sin_addr.s_addr;
-  }
-  else if (addr1->ss.ss_family == AF_INET6)
-  {
-    const struct sockaddr_in6 *const sin1 = (const struct sockaddr_in6 *)addr1;
-    const struct sockaddr_in6 *const sin2 = (const struct sockaddr_in6 *)addr2;
-
-    if (port == true && (sin1->sin6_port != sin2->sin6_port))
-      return false;
-
-    return memcmp(sin1->sin6_addr.s6_addr,
-                  sin2->sin6_addr.s6_addr, sizeof(struct in6_addr)) == 0;
-  }
-
-  return false;
-}
