@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 2000 Kevin L. Mitchell <klmitch@mit.edu>
- *  Copyright (c) 2013-2020 ircd-hybrid development team
+ *  Copyright (c) 2013-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file motd.c
  * \brief Message-of-the-day manipulation implementation.
- * \version $Id: motd.c 9364 2020-04-30 19:24:10Z michael $
+ * \version $Id: motd.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -241,20 +241,16 @@ motd_lookup(const struct Client *client)
           return motd;
         break;
       }
+
       case MOTD_HOSTMASK:
         if (match(motd->mask, client->realhost) == 0 ||
             match(motd->mask, client->sockhost) == 0 || match(motd->mask, client->host) == 0)
           return motd;
         break;
-      case MOTD_IPMASKV4:
-        if (client->ip.ss.ss_family == AF_INET)
-          if (match_ipv4(&client->ip, &motd->address, motd->addrbits))
-            return motd;
-        break;
       case MOTD_IPMASKV6:
-        if (client->ip.ss.ss_family == AF_INET6)
-          if (match_ipv6(&client->ip, &motd->address, motd->addrbits))
-            return motd;
+      case MOTD_IPMASKV4:
+        if (address_compare(&client->ip, &motd->address, false, false, motd->addrbits) == true)
+          return motd;
         break;
       default: break;
     }
@@ -443,6 +439,7 @@ motd_memory_count(struct Client *client)
     ++mt;
     mtm += sizeof(struct Motd);
     mtm += motd->path ? (strlen(motd->path) + 1) : 0;
+    mtm += motd->mask ? (strlen(motd->mask) + 1) : 0;
   }
 
   DLINK_FOREACH(node, MotdList.cachelist.head)
@@ -451,6 +448,7 @@ motd_memory_count(struct Client *client)
 
     ++mtc;
     mtcm += sizeof(struct MotdCache) + (MOTD_LINESIZE * (cache->count - 1));
+    mtcm += cache->path ? (strlen(cache->path) + 1) : 0;
   }
 
   sendto_one_numeric(client, &me, RPL_STATSDEBUG | SND_EXPLICIT,
