@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file res.c
  * \brief ircd resolver functions
- * \version $Id: res.c 9201 2020-01-24 23:51:50Z michael $
+ * \version $Id: res.c 9874 2021-01-04 11:46:16Z michael $
  */
 
 /*
@@ -55,6 +55,8 @@
 #include "res.h"
 #include "reslib.h"
 #include "memory.h"
+#include "conf.h"
+#include "hostmask.h"
 
 #if (CHAR_BIT != 8)
 #error this code needs to be able to address individual octets
@@ -141,7 +143,7 @@ static bool
 res_ourserver(const struct irc_ssaddr *inp)
 {
   for (unsigned int i = 0; i < irc_nscount; ++i)
-    if (address_compare(inp, &irc_nsaddr_list[i], true) == true)
+    if (address_compare(inp, &irc_nsaddr_list[i], true, true, 0) == true)
       return true;
 
   return false;
@@ -596,8 +598,6 @@ res_readreply(fde_t *F, void *data)
       (*request->callback)(request->callback_ctx, &request->addr, request->name, request->namelength);
       rem_request(request);
     }
-
-    continue;
   }
 
   comm_setselect(F, COMM_SELECT_READ, res_readreply, NULL, 0);
@@ -607,11 +607,10 @@ res_readreply(fde_t *F, void *data)
  * timeout_query_list - Remove queries from the list which have been
  * there too long without being resolved.
  */
-static uintmax_t
-timeout_query_list(void)
+static void
+resolver_timeout(void *unused)
 {
   dlink_node *node, *node_next;
-  uintmax_t next_time = 0;
 
   DLINK_FOREACH_SAFE(node, node_next, request_list.head)
   {
@@ -624,7 +623,6 @@ timeout_query_list(void)
       {
         (*request->callback)(request->callback_ctx, NULL, NULL, 0);
         rem_request(request);
-        continue;
       }
       else
       {
@@ -633,21 +631,7 @@ timeout_query_list(void)
         resend_query(request);
       }
     }
-
-    if (next_time == 0 || timeout < next_time)
-      next_time = timeout;
   }
-
-  return (next_time > event_base->time.sec_monotonic) ? next_time : (event_base->time.sec_monotonic + AR_TTL);
-}
-
-/*
- * timeout_resolver - check request list
- */
-static void
-timeout_resolver(void *unused)
-{
-  timeout_query_list();
 }
 
 /*
@@ -656,13 +640,13 @@ timeout_resolver(void *unused)
 void
 resolver_init(void)
 {
-  static struct event event_timeout_resolver =
+  static struct event resolver_timeout_event =
   {
-    .name = "timeout_resolver",
-    .handler = timeout_resolver,
+    .name = "resolver_timeout",
+    .handler = resolver_timeout,
     .when = 1
   };
 
   start_resolver();
-  event_add(&event_timeout_resolver, NULL);
+  event_add(&resolver_timeout_event, NULL);
 }
