@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd.c
  * \brief Network functions.
- * \version $Id: s_bsd.c 9249 2020-02-01 13:35:32Z michael $
+ * \version $Id: s_bsd.c 9891 2021-01-16 18:20:44Z michael $
  */
 
 #include "stdinc.h"
@@ -183,7 +183,7 @@ ssl_handshake(fde_t *F, void *data)
 
   comm_settimeout(F, 0, NULL, NULL);
 
-  if (tls_verify_certificate(&F->tls, ConfigServerInfo.message_digest_algorithm, &client->certfp) == false)
+  if (tls_verify_certificate(&F->tls, ConfigServerInfo.message_digest_algorithm, &client->tls_certfp) == false)
     ilog(LOG_TYPE_IRCD, "Client %s gave bad TLS client certificate",
          client_get_name(client, MASK_IP));
 
@@ -202,8 +202,8 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
 {
   struct Client *client = client_make(NULL);
 
-  client->connection->fd = fd_open(fd, true, (listener->flags & LISTENER_TLS) ?
-                                     "Incoming TLS connection" : "Incoming connection");
+  client->connection->fd = fd_open(fd, true, listener_has_flag(listener, LISTENER_TLS) ?
+                                   "Incoming TLS connection" : "Incoming connection");
 
   /*
    * copy address to 'sockhost' as a string, copy it to host too
@@ -215,10 +215,11 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
               client->ip.ss_len, client->sockhost,
               sizeof(client->sockhost), NULL, 0, NI_NUMERICHOST);
 
-  if (client->sockhost[0] == ':')
+  if (client->sockhost[0] == ':' &&
+      client->sockhost[1] == ':')
   {
-    client->sockhost[0] = '0';
     memmove(client->sockhost + 1, client->sockhost, sizeof(client->sockhost) - 1);
+    client->sockhost[0] = '0';
   }
 
   strlcpy(client->host, client->sockhost, sizeof(client->host));
@@ -226,7 +227,7 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
   client->connection->listener = listener;
   ++listener->ref_count;
 
-  if (listener->flags & LISTENER_TLS)
+  if (listener_has_flag(listener, LISTENER_TLS))
   {
     if (tls_new(&client->connection->fd->tls, fd, TLS_ROLE_SERVER) == false)
     {
@@ -280,7 +281,7 @@ comm_settimeout(fde_t *F, uintmax_t timeout, void (*callback)(fde_t *, void *),
   assert(F);
   assert(F->flags.open == true);
 
-  F->timeout = event_base->time.sec_monotonic + timeout;
+  F->timeout = timeout ? event_base->time.sec_monotonic + timeout : 0;
   F->timeout_handler = callback;
   F->timeout_data = cbdata;
 }
@@ -303,7 +304,7 @@ comm_setflush(fde_t *F, uintmax_t timeout, void (*callback)(fde_t *, void *), vo
   assert(F);
   assert(F->flags.open == true);
 
-  F->flush_timeout = event_base->time.sec_monotonic + timeout;
+  F->flush_timeout = timeout ? event_base->time.sec_monotonic + timeout : 0;
   F->flush_handler = callback;
   F->flush_data = cbdata;
 }
@@ -318,9 +319,6 @@ comm_setflush(fde_t *F, uintmax_t timeout, void (*callback)(fde_t *, void *), vo
 void
 comm_checktimeouts(void *unused)
 {
-  void (*hdl)(fde_t *, void *);
-  void *data;
-
   for (int fd = 0; fd <= highest_fd; ++fd)
   {
     fde_t *F = &fd_table[fd];
@@ -329,23 +327,21 @@ comm_checktimeouts(void *unused)
       continue;
 
     /* check flush functions */
-    if (F->flush_handler && F->flush_timeout > 0 &&
-        F->flush_timeout < event_base->time.sec_monotonic)
+    if (F->flush_timeout && F->flush_timeout < event_base->time.sec_monotonic)
     {
-      hdl = F->flush_handler;
-      data = F->flush_data;
+      void (*hdl)(fde_t *, void *) = F->flush_handler;
+      void *data = F->flush_data;
 
       comm_setflush(F, 0, NULL, NULL);
       hdl(F, data);
     }
 
     /* check timeouts */
-    if (F->timeout_handler && F->timeout > 0 &&
-        F->timeout < event_base->time.sec_monotonic)
+    if (F->timeout && F->timeout < event_base->time.sec_monotonic)
     {
       /* Call timeout handler */
-      hdl = F->timeout_handler;
-      data = F->timeout_data;
+      void (*hdl)(fde_t *, void *) = F->timeout_handler;
+      void *data = F->timeout_data;
 
       comm_settimeout(F, 0, NULL, NULL);
       hdl(F, data);
