@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file server.c
  * \brief Server related functions.
- * \version $Id$
+ * \version $Id: server.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -482,13 +482,12 @@ server_finish_tls_handshake(struct Client *client)
   /* Next, send the initial handshake */
   SetHandshake(client);
 
-  sendto_one(client, "PASS %s TS %u %s", conf->spasswd, TS_CURRENT, me.id);
+  sendto_one(client, "PASS %s", conf->spasswd);
 
   sendto_one(client, "CAPAB :%s", capab_get(NULL));
 
-  sendto_one(client, "SERVER %s 1 :%s%s",
-             me.name, ConfigServerHide.hidden ? "(H) " : "",
-             me.info);
+  sendto_one(client, "SERVER %s 1 %s +%s :%s",
+             me.name, me.id, ConfigServerHide.hidden ? "h" : "", me.info);
 
   /* If we get here, we're ok, so lets start reading some data */
   read_packet(client->connection->fd, client); 
@@ -627,12 +626,12 @@ server_connect_callback(fde_t *F, int status, void *data)
   /* Next, send the initial handshake */
   SetHandshake(client);
 
-  sendto_one(client, "PASS %s TS %u %s", conf->spasswd, TS_CURRENT, me.id);
+  sendto_one(client, "PASS %s", conf->spasswd);
 
   sendto_one(client, "CAPAB :%s", capab_get(NULL));
 
-  sendto_one(client, "SERVER %s 1 :%s%s", me.name,
-             ConfigServerHide.hidden ? "(H) " : "", me.info);
+  sendto_one(client, "SERVER %s 1 %s +%s :%s",
+             me.name, me.id, ConfigServerHide.hidden ? "h" : "", me.info);
 
   /* If we get here, we're ok, so lets start reading some data */
   read_packet(client->connection->fd, client);
