@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2015-2020 ircd-hybrid development team
+ *  Copyright (c) 2015-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /*! \file tls_gnutls.c
  * \brief Includes all GnuTLS-specific TLS functions
- * \version $Id: tls_gnutls.c 9223 2020-01-26 11:35:22Z michael $
+ * \version $Id: tls_gnutls.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -202,11 +202,11 @@ tls_free(tls_data_t *tls_data)
 ssize_t
 tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, bool *want_write)
 {
-  ssize_t length = gnutls_record_recv(tls_data->session, buf, bufsize);
+  ssize_t ret = gnutls_record_recv(tls_data->session, buf, bufsize);
 
-  if (length <= 0)
+  if (ret <= 0)
   {
-    switch (length)
+    switch (ret)
     {
       case GNUTLS_E_AGAIN:
       case GNUTLS_E_INTERRUPTED:
@@ -214,22 +214,22 @@ tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, bool *want_write)
         return -1;
       case 0:  /* Closed */
       default:  /* Other error */
-        /* XXX can gnutls_strerror(length) if <0 for gnutls's idea of the reason */
+        /* XXX can gnutls_strerror(ret) if <0 for gnutls's idea of the reason */
         return 0;
     }
   }
 
-  return length;
+  return ret;
 }
 
 ssize_t
 tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, bool *want_read)
 {
-  ssize_t length = gnutls_record_send(tls_data->session, buf, bufsize);
+  ssize_t ret = gnutls_record_send(tls_data->session, buf, bufsize);
 
-  if (length <= 0)
+  if (ret <= 0)
   {
-    switch (length)
+    switch (ret)
     {
       case GNUTLS_E_AGAIN:
       case GNUTLS_E_INTERRUPTED:
@@ -241,7 +241,7 @@ tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, bool *want_read
     }
   }
 
-  return length;
+  return ret;
 }
 
 void
@@ -287,7 +287,7 @@ tls_set_ciphers(tls_data_t *tls_data, const char *cipher_list)
   if (ret != GNUTLS_E_SUCCESS)
   {
     /* GnuTLS did not understand the user supplied string, log and fall back to the default priorities */
-    ilog(LOG_TYPE_IRCD, "Failed to set GnuTLS priorities to \"%s\": %s Syntax error at position %u, falling back to default %",
+    ilog(LOG_TYPE_IRCD, "Failed to set GnuTLS priorities to \"%s\": %s Syntax error at position %u, falling back to default %s",
          cipher_list, gnutls_strerror(ret), (unsigned int)(prioerror - cipher_list), tls_default_priority_string);
     gnutls_priority_init(&tls_data->context->priorities, tls_default_priority_string, NULL);
     return false;
