@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2005-2020 ircd-hybrid development team
+ *  Copyright (c) 2005-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /*! \file tls_openssl.c
  * \brief Includes all OpenSSL-specific TLS functions
- * \version $Id: tls_openssl.c 9223 2020-01-26 11:35:22Z michael $
+ * \version $Id: tls_openssl.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -227,13 +227,14 @@ tls_free(tls_data_t *tls_data)
 ssize_t
 tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, bool *want_write)
 {
-  SSL *ssl = *tls_data;
-  ssize_t length = SSL_read(ssl, buf, bufsize);
+  ERR_clear_error();
 
+  SSL *ssl = *tls_data;
+  ssize_t ret = SSL_read(ssl, buf, bufsize);
   /* Translate openssl error codes, sigh */
-  if (length < 0)
+  if (ret < 0)
   {
-    switch (SSL_get_error(ssl, length))
+    switch (SSL_get_error(ssl, ret))
     {
       case SSL_ERROR_WANT_WRITE:
       {
@@ -250,23 +251,24 @@ tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, bool *want_write)
           break;
       /* Fall through */
       default:
-        length = errno = 0;
+        ret = errno = 0;
     }
   }
 
-  return length;
+  return ret;
 }
 
 ssize_t
 tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, bool *want_read)
 {
-  SSL *ssl = *tls_data;
-  ssize_t retlen = SSL_write(ssl, buf, bufsize);
+  ERR_clear_error();
 
+  SSL *ssl = *tls_data;
+  ssize_t ret = SSL_write(ssl, buf, bufsize);
   /* Translate openssl error codes, sigh */
-  if (retlen < 0)
+  if (ret < 0)
   {
-    switch (SSL_get_error(ssl, retlen))
+    switch (SSL_get_error(ssl, ret))
     {
       case SSL_ERROR_WANT_READ:
         *want_read = true;
@@ -281,11 +283,11 @@ tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, bool *want_read
           break;
       /* Fall through */
       default:
-        retlen = errno = 0;  /* Either an SSL-specific error or EOF */
+        ret = errno = 0;  /* Either an SSL-specific error or EOF */
     }
   }
 
-  return retlen;
+  return ret;
 }
 
 void
@@ -337,6 +339,8 @@ tls_handshake(tls_data_t *tls_data, tls_role_t role, const char **errstr)
   SSL *ssl = *tls_data;
   int ret;
 
+  ERR_clear_error();
+
   if (role == TLS_ROLE_SERVER)
     ret = SSL_accept(ssl);
   else
