@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2020 ircd-hybrid development team
+ *  Copyright (c) 1997-2021 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file whowas.c
  * \brief WHOWAS user cache.
- * \version $Id: whowas.c 9249 2020-02-01 13:35:32Z michael $
+ * \version $Id: whowas.c 9858 2021-01-01 04:43:42Z michael $
  */
 
 #include "stdinc.h"
@@ -57,11 +57,11 @@ whowas_get_hash(unsigned int hash_value)
 static struct Whowas *
 whowas_unlink(struct Whowas *whowas)
 {
-  if (whowas->online)
-    dlinkDelete(&whowas->cnode, &whowas->online->whowas_list);
+  if (whowas->client)
+    dlinkDelete(&whowas->client_list_node, &whowas->client->whowas_list);
 
-  dlinkDelete(&whowas->hnode, &whowas_hash[whowas->hash_value]);
-  dlinkDelete(&whowas->lnode, &whowas_list);
+  dlinkDelete(&whowas->hash_node, &whowas_hash[whowas->hash_value]);
+  dlinkDelete(&whowas->list_node, &whowas_list);
 
   return whowas;
 }
@@ -135,14 +135,14 @@ whowas_add_history(struct Client *client, bool online)
 
   if (online == true)
   {
-    whowas->online = client;
-    dlinkAdd(whowas, &whowas->cnode, &client->whowas_list);
+    whowas->client = client;
+    dlinkAdd(whowas, &whowas->client_list_node, &client->whowas_list);
   }
   else
-    whowas->online = NULL;
+    whowas->client = NULL;
 
-  dlinkAdd(whowas, &whowas->hnode, &whowas_hash[whowas->hash_value]);
-  dlinkAdd(whowas, &whowas->lnode, &whowas_list);
+  dlinkAdd(whowas, &whowas->hash_node, &whowas_hash[whowas->hash_value]);
+  dlinkAdd(whowas, &whowas->list_node, &whowas_list);
 }
 
 /*! \brief This must be called when the client structure is about to
@@ -157,8 +157,8 @@ whowas_off_history(struct Client *client)
   {
     struct Whowas *whowas = client->whowas_list.head->data;
 
-    whowas->online = NULL;
-    dlinkDelete(&whowas->cnode, &client->whowas_list);
+    whowas->client = NULL;
+    dlinkDelete(&whowas->client_list_node, &client->whowas_list);
   }
 }
 
@@ -183,7 +183,7 @@ whowas_get_history(const char *name, uintmax_t timelimit)
       continue;
     if (irccmp(name, whowas->name))
       continue;
-    return whowas->online;
+    return whowas->client;
   }
 
   return NULL;
